@@ -79,28 +79,27 @@ get_index_file (STRING path, BTREE btr, FKEY ikey)
 INDEX
 readindex (BTREE btr, FKEY ikey, BOOLEAN robust)
 {
-	FILE *fp=NULL;
+	FILE *fi=NULL;
 	INDEX index=NULL;
-	char scratch[200];
+	char scratch[400];
 	get_index_file(scratch, btr, ikey);
-	if ((fp = fopen(scratch, LLREADBINARY)) == NULL) {
+	if ((fi = fopen(scratch, LLREADBINARY LLFILERANDOM)) == NULL) {
 		if (robust) {
-			bterrno = BTERR_INDEX;
+			/* fall to end & return NULL */
 			goto readindex_end;
 		}
 		sprintf(scratch, "Missing index file: %s", fkey2path(ikey));
 		FATAL2(scratch);
 	}
 	index = (INDEX) stdalloc(BUFLEN);
-	if (fread(index, BUFLEN, 1, fp) != 1) {
+	if (fread(index, BUFLEN, 1, fi) != 1) {
 		if (robust) {
-			bterrno = BTERR_INDEX;
 			goto readindex_end;
 		}
 		sprintf(scratch, "Undersized (<%d) index file: %s", BUFLEN, fkey2path(ikey));
 		FATAL2(scratch);
 	}
-	if (fp) fclose(fp);
+	if (fi) fclose(fi);
 readindex_end:
 	return index;
 }
@@ -112,20 +111,18 @@ readindex_end:
 void
 writeindex (BTREE btr, INDEX index)
 {
-	FILE *fp;
-	char scratch[200];
+	FILE *fi=NULL;
+	char scratch[400];
 	get_index_file(scratch, btr, ixself(index));
-	if ((fp = fopen(scratch, LLWRITEBINARY)) == NULL) {
-		/* Needs to be revisited with double-buffering */
+	if ((fi = fopen(scratch, LLWRITEBINARY LLFILERANDOM)) == NULL) {
 		sprintf(scratch, "Error opening index file: %s", fkey2path(ixself(index)));
 		FATAL2(scratch);
 	}
-	if (fwrite(index, BUFLEN, 1, fp) != 1) {
-		/* Needs to be revisited with double-buffering */
-		sprintf(scratch, "Error writng index file: %s", fkey2path(ixself(index)));
+	if (fwrite(index, BUFLEN, 1, fi) != 1) {
+		sprintf(scratch, "Error writing index file: %s", fkey2path(ixself(index)));
 		FATAL2(scratch);
 	}
-	fclose(fp);
+	if (fclose(fi) != 0) FATAL2(scratch);
 }
 /*==============================================
  * initcache -- Initialize index cache for btree
