@@ -17,6 +17,7 @@ NODE is_cel_loaded(CACHEEL cel);
 /* llgettext.c */
 void init_win32_gettext_shim(void);
 void llgettext_init(CNSTRING domain, CNSTRING codeset);
+void update_textdomain_localedir(CNSTRING domain, CNSTRING prefix);
 
 /* names.c */
 RECORD id_by_key(CNSTRING name, char ctype);
@@ -36,6 +37,6 @@ void record_set_cel(RECORD rec, CACHEEL cel);
 
 /* xreffile.c */
 BOOLEAN xrefs_get_counts_from_unopened_db(CNSTRING path, INT *nindis, INT *nfams
-	, INT *nsours, INT *nevens, INT *nothrs);
+	, INT *nsours, INT *nevens, INT *nothrs, char ** errptr);
 
 #endif /* _GEDCOM_PRIV_H */
