@@ -1808,13 +1808,14 @@ refn_to_indiseq (STRING ukey, INT letr, INT sort)
  * key_to_indiseq -- Return person sequence of the matching key
  *  name:  [IN]  name to search for
  *  ctype: [IN]  type of record (eg, 'I') (0 for any)
+ * returns NULL if name is empty or not found
  *=============================================================*/
 INDISEQ
 key_to_indiseq (STRING name, char ctype)
 {
-	STRING key;
+	STRING key=0;
 	INDISEQ seq = NULL;
-	RECORD rec;
+	RECORD rec=0;
 	if (!name) return NULL;
 	rec = id_by_key(name, ctype);
 	if (!rec) return NULL;
@@ -1824,6 +1825,24 @@ key_to_indiseq (STRING name, char ctype)
 	append_indiseq_null(seq, key, NULL, FALSE, FALSE);
 	return seq;
 }
+/*=============================================================
+ * rec_to_indiseq -- Return new sequence containing specified record
+ *  rec:  [IN]  record to put in list
+ * returns NULL if record is null
+ *=============================================================*/
+#ifdef UNUSED_CODE
+INDISEQ
+rec_to_indiseq (RECORD rec)
+{
+	STRING key=0;
+	INDISEQ seq = NULL;
+	if (!rec) return NULL;
+	key = rmvat(nxref(nztop(rec)));
+	seq = create_indiseq_null();
+	append_indiseq_null(seq, key, NULL, FALSE, FALSE);
+	return seq;
+}
+#endif /* UNUSED CODE */
 /*===========================================================
  * str_to_indiseq -- Return person sequence matching a string
  *  name:  [IN]  name to search for
@@ -1995,7 +2014,7 @@ get_all_even (void)
 		static char skey[10];
 		if (!seq)
 			seq = create_indiseq_ival();
-		sprintf(skey, "E%d", i);
+		sprintf(skey, "E%ld", i);
 		append_indiseq_ival(seq, skey, NULL, i, TRUE, FALSE);
 	}
 	return seq;
@@ -2014,7 +2033,7 @@ get_all_othe (void)
 		static char skey[10];
 		if (!seq)
 			seq = create_indiseq_ival();
-		sprintf(skey, "X%d", i);
+		sprintf(skey, "X%ld", i);
 		append_indiseq_ival(seq, skey, NULL, i, TRUE, FALSE);
 	}
 	return seq;
@@ -2044,7 +2063,8 @@ indiseq_is_valtype_null (INDISEQ seq)
 INT
 get_indiseq_ival (INDISEQ seq, INT i)
 {
-	ASSERT(i >= 0 && i < ISize(seq));
+	ASSERT(i >= 0);
+	ASSERT(i < ISize(seq));
 	ASSERT(IValtype(seq) == ISVAL_INT || IValtype(seq) == ISVAL_NUL);
 	return sval(IData(seq)[i]).i;
 
@@ -2150,7 +2170,9 @@ calc_indiseq_name_el (INDISEQ seq, INT index)
 {
 	STRING key, name;
 
-	ASSERT(seq && index>=0 && index<ISize(seq));
+	ASSERT(seq);
+	ASSERT(index>=0);
+	ASSERT(index<ISize(seq));
 
 	if (IFlags(seq) & WITHNAMES)
 		return;
