@@ -58,15 +58,17 @@ struct tag_cacheel {
 	CACHEEL c_prev;   /* previous el */
 	CACHEEL c_next;   /* next el */
 	STRING c_key;     /* record key */
-	INT c_lock;       /* locked? */
+	INT c_lock;       /* lock count (includes report locks) */
+	INT c_rptlock;    /* report lock count */
 	RECORD c_record;
 };
-#define cnode(e) ((e)->c_node)
-#define cprev(e) ((e)->c_prev)
-#define cnext(e) ((e)->c_next)
-#define ckey(e)  ((e)->c_key)
-#define cclock(e) ((e)->c_lock)
-#define crecord(e) ((e)->c_record)
+#define cnode(e)      ((e)->c_node)
+#define cprev(e)      ((e)->c_prev)
+#define cnext(e)      ((e)->c_next)
+#define ckey(e)       ((e)->c_key)
+#define cclock(e)     ((e)->c_lock)
+#define ccrptlock(e)  ((e)->c_rptlock)
+#define crecord(e)    ((e)->c_record)
 
 /*==============================
  * CACHE -- Internal cache type.
@@ -608,7 +610,8 @@ remove_direct (CACHE cache, CACHEEL cel)
 {
 	CACHEEL prev = cprev(cel);
 	CACHEEL next = cnext(cel);
-	ASSERT(cache && cel);
+	ASSERT(cache);
+	ASSERT(cel);
 	if (prev) cnext(prev) = next;
 	if (next) cprev(next) = prev;
 	if (!prev) cacfirstdir(cache) = next;
@@ -622,7 +625,8 @@ static void
 first_direct (CACHE cache, CACHEEL cel)
 {
 	CACHEEL frst = cacfirstdir(cache);
-	ASSERT(cache && cel);
+	ASSERT(cache);
+	ASSERT(cel);
 	cacsizedir(cache)++;
 	cprev(cel) = NULL;
 	cnext(cel) = frst;
@@ -636,7 +640,8 @@ first_direct (CACHE cache, CACHEEL cel)
 static void
 direct_to_first (CACHE cache, CACHEEL cel)
 {
-	ASSERT(cache && cel);
+	ASSERT(cache);
+	ASSERT(cel);
 	if (cel == cacfirstdir(cache)) return;
 	remove_direct(cache, cel);
 	first_direct(cache, cel);
@@ -660,13 +665,15 @@ add_to_direct (CACHE cache, CNSTRING key, INT reportmode)
 	RECORD rec=0;
 	int i, j;
 
-	ASSERT(cache && key);
+	ASSERT(cache);
+	ASSERT(key);
 	rec = NULL;
 	if ((rawrec = retrieve_raw_record(key, &len))) 
 		/* 2003-11-22, we should use string_to_node here */
 		rec = string_to_record(rawrec, key, len);
 	if (!rec)
 	{
+		ZSTR zstr=zs_newn(256);
 		if(listbadkeys) {
 			if(strlen(badkeylist) < 80 - strlen(key) - 2) {
 				if (badkeylist[0])
@@ -676,16 +683,20 @@ add_to_direct (CACHE cache, CNSTRING key, INT reportmode)
 			return(NULL);
 		}
 		if (reportmode) return(NULL);
-		crashlog("key %s is not in database. Use \"btedit <database> <key>\" to fix.\n", (char *) key);
-		crashlog("where <key> is probably one of the following:\n");
+		crashlogn(_("Database error caused by reference to nonexisting key <%s>."), (char *)key);
+		crashlogn(_("It might be possible to fix this with btedit."));
+		zs_sets(zstr, _("Neighboring keys include:"));
 		for(i = 0; i < 10; i++)
 		{
 			j = keyidx + i;
 			if(j >= 10) j -= 10;
-			if (keybuf[j][0])
-				crashlog(" %s", (char *)keybuf[j]);
+			if (keybuf[j][0]) {
+				zs_appc(zstr, ' ');
+				zs_apps(zstr, keybuf[j]);
+			}
 		}
-		crashlog("\n");
+		crashlogn(zs_str(zstr));
+		zs_free(&zstr);
 		/* deliberately fall through to let ASSERT(rec) fail */
 	}
 	ASSERT(rec);
@@ -740,7 +751,8 @@ static NODE
 key_typed_to_node (CACHE cache, CNSTRING key, STRING tag)
 {
 	CACHEEL cel;
-	ASSERT(cache && key);
+	ASSERT(cache);
+	ASSERT(key);
 	if (!(cel = key_to_cacheel(cache, key, tag, FALSE)))
 		return NULL;
 	return cnode(cel);
@@ -754,7 +766,8 @@ static RECORD
 key_typed_to_record (CACHE cache, CNSTRING key, STRING tag)
 {
 	CACHEEL cel;
-	ASSERT(cache && key);
+	ASSERT(cache);
+	ASSERT(key);
 	if (!(cel = key_to_cacheel(cache, key, tag, FALSE)))
 		return NULL;
 	return get_record_for_cel(cel);
@@ -817,7 +830,8 @@ qkey_typed_to_record (CACHE cache, CNSTRING key, STRING tag)
 	CACHEEL cel=0;
 	RECORD rec=0;
 
-	ASSERT(cache && key);
+	ASSERT(cache);
+	ASSERT(key);
 	if (!(cel = key_to_cacheel(cache, key, tag, TRUE)))
 		return NULL;
 	rec = get_record_for_cel(cel);
@@ -830,9 +844,30 @@ void
 lock_cache (CACHEEL cel)
 {
 	ASSERT(cnode(cel)); /* must be in direct */
-	cclock(cel)++;
+	++cclock(cel);
 	ASSERT(cclock(cel)>0);
 }
+/*======================================
+ * lockrpt_cache -- Lock CACHEEL into direct cache (for report program)
+ *====================================*/
+void
+lockrpt_cache (CACHEEL cel)
+{
+	ASSERT(cnode(cel)); /* must be in direct */
+	/* put real lock on to actually lock it */
+	++cclock(cel);
+	/* put report lock on, so we can free orphaned report locks */
+	++ccrptlock(cel);
+	ASSERT(cclock(cel)>0);
+}
+/*======================================
+ * cel_rptlocks -- return report lock count for specified cache element
+ *====================================*/
+INT
+cel_rptlocks (CACHEEL cel)
+{
+	return ccrptlock(cel);
+}
 /*======================================
  * lock_record_in_cache -- Load record into cache & lock it
  *====================================*/
@@ -853,9 +888,21 @@ lock_record_in_cache (RECORD rec)
 void
 unlock_cache (CACHEEL cel)
 {
-	ASSERT(cclock(cel)>0);
+	ASSERT(cclock(cel) > 0);
 	ASSERT(cnode(cel));
-	cclock(cel)--;
+	--cclock(cel);
+}
+/*==========================================
+ * unlockrpt_cache -- Unlock CACHEEL from direct cache (report program call)
+ *========================================*/
+void
+unlockrpt_cache (CACHEEL cel)
+{
+	ASSERT(cclock(cel) > 0);
+	ASSERT(ccrptlock(cel) > 0);
+	ASSERT(cnode(cel));
+	--cclock(cel);
+	--ccrptlock(cel);
 }
 /*======================================
  * unlock_record_from_cache -- Remove lock on record
@@ -872,6 +919,8 @@ unlock_record_from_cache (RECORD rec)
 }
 /*=========================================
  * cache_get_lock_counts -- Fill in lock counts
+ * does not include report locks (but, this isn't
+ *  called during reports anyway)
  *=======================================*/
 static void
 cache_get_lock_counts (CACHE ca, INT * locks)
@@ -988,7 +1037,8 @@ node_to_cache (CACHE cache, NODE top)
 	CACHEEL cel=0;
 	ASSERT(cache);
 	ASSERT(top);
-	ASSERT(!nparent(top) && !nsibling(top)); /* should be a root */
+	ASSERT(!nparent(top));	/* should be a root */
+	ASSERT(!nsibling(top)); /* should be a root */
 	if (nestr(cacname(cache), "OTHR")) {
 		/* only INDI records in INDI cache, etc */
 		if (!eqstr(cacname(cache), ntag(top))) {
@@ -1019,7 +1069,7 @@ get_free_cacheel (CACHE cache)
 		for (cel = caclastdir(cache); cel && cclock(cel); cel = cprev(cel)) {
 		}
 		if (!cel) {
-			llwprintf("Cache overflow! (Cache=%s, size=%d)\n", cacname(cache), cacmaxdir(cache));
+			crashlog(_("Cache [%s] overflowed its max size (%d)"), cacname(cache), cacmaxdir(cache));
 			ASSERT(0);
 		}
 		remove_from_cache(cache, ckey(cel));
@@ -1071,7 +1121,8 @@ static void
 put_node_in_cache (CACHE cache, CACHEEL cel, NODE node, STRING key)
 {
 	BOOLEAN travdone = FALSE;
-	ASSERT(cache && node);
+	ASSERT(cache);
+	ASSERT(node);
 	ASSERT(cacsizedir(cache) < cacmaxdir(cache));
 	init_cel(cel);
 	insert_table_ptr(cacdata(cache), key, cel);
@@ -1377,7 +1428,8 @@ static CACHEEL
 qkey_to_typed_cacheel (STRING key)
 {
 	char ntype;
-	ASSERT(key && key[0]);
+	ASSERT(key);
+	ASSERT(key[0]);
 	ntype = key[0];
 	switch(ntype) {
 	case 'I': return qkey_to_indi_cacheel(key);
@@ -1447,3 +1499,39 @@ set_all_nodetree_to_root_cel (NODE root)
 {
 	set_all_nodetree_to_cel(root, root->n_cel);
 }
+/*=======================================================
+ * free_all_rprtlocks_in_cache -- Remove any rptlocks on any
+ *  elements in this cache, and return number removed
+ *=====================================================*/
+static int
+free_all_rprtlocks_in_cache (CACHE cache)
+{
+	INT ct=0;
+	CACHEEL cel=0;
+
+	for (cel = caclastdir(cache); cel; cel = cprev(cel)) {
+		if (ccrptlock(cel)) {
+			INT delta = ccrptlock(cel);
+			ccrptlock(cel) = 0;
+			ASSERT(cclock(cel) >= delta);
+			cclock(cel) -= delta;
+			++ct;
+		}
+	}
+	return ct;
+}
+/*=======================================================
+ * free_all_rprtlocks -- Remove any rptlocks on any
+ *  elements in all caches, and return number removed
+ *=====================================================*/
+int
+free_all_rprtlocks (void)
+{
+	int ct=0;
+	ct += free_all_rprtlocks_in_cache(indicache);
+	ct += free_all_rprtlocks_in_cache(famcache);
+	ct += free_all_rprtlocks_in_cache(sourcache);
+	ct += free_all_rprtlocks_in_cache(sourcache);
+	ct += free_all_rprtlocks_in_cache(othrcache);
+	return ct;
+}
