@@ -33,7 +33,7 @@ extern STRING qSopt2long;
 /* alphabetical */
 static void copy_process(STRING dest, STRING src);
 static void expand_variables(STRING valbuf, INT max);
-static BOOLEAN load_config_file(STRING file, STRING * pmsg);
+static INT load_config_file(STRING file, STRING * pmsg, STRING *chain);
 static void send_notifications(void);
 
 /*********************************************
@@ -71,22 +71,26 @@ static void
 copy_process (STRING dest, STRING src)
 {
 	STRING q=dest,p=src;
-	char c;
-	while ((*q++ = c = *p++)) {
-		if (c == '\\') {
-			if (!(c = *p++)) {
-				*q = 0;
+	while ((*q = *p++)) {
+		if (*q == '\\') {
+			switch (*p++) {
+			case 0:
+				*++q = 0;
 				break;
-			}
-			if (c == 'n')
-				q[-1] = '\n';
-			else if (c == 't')
-				q[-1] = '\t';
-			else if (c == '\\')
-				q[-1] = '\\';
-			else
+			case 'n':
+				*q = '\n';
+				break;
+			case 't':
+				*q  = '\t';
+				break;
+			case '\\':
+				*q = '\\';
+				break;
+			default:
 				--p;
+			}
 		}
+		++q;
 	}
 }
 /*==========================================
@@ -139,21 +143,22 @@ dir_from_file (STRING file)
 /*==========================================
  * load_config_file -- read options in config file
  *  and load into table (f_global)
- * Created: 2001/02/04, Perry Rapp
+ * returns 1 for success, 0 for not found, -1 for error (with pmsg)
  *========================================*/
-static BOOLEAN
-load_config_file (STRING file, STRING * pmsg)
+static INT
+load_config_file (STRING file, STRING * pmsg, STRING *chain)
 {
 	FILE * fp = 0;
 	STRING ptr, val, key;
 	STRING thisdir = dir_from_file(file);
 	BOOLEAN failed, noesc;
 	char buffer[MAXLINELEN],valbuf[MAXLINELEN];
+	INT len;
 	fp = fopen(file, LLREADTEXT);
 	if (!fp) {
-	        free(thisdir);
-		return TRUE; /* no config file, that is ok */
-        }
+		free(thisdir);
+		return 0; /* 0 for not found */
+	}
 	f_predef = create_table_str();
 
 	insert_table_str(f_predef, "%thisdir%", thisdir);
@@ -161,9 +166,12 @@ load_config_file (STRING file, STRING * pmsg)
 	/* read thru config file til done (or error) */
 	while (fgets(buffer, sizeof(buffer), fp)) {
 		noesc = FALSE;
+		len = strlen(buffer);
+		if (len == 0)
+			continue; /* ignore blank lines */
 		if (buffer[0] == '#')
 			continue; /* ignore lines starting with # */
-		if (!feof(fp) && buffer[strlen(buffer)-1] != '\n') {
+		if (!feof(fp) && buffer[len-1] != '\n') {
 			/* bail out if line too long */
 			break;
 		}
@@ -193,33 +201,54 @@ load_config_file (STRING file, STRING * pmsg)
 		expand_variables(valbuf, sizeof(valbuf));
 		key = buffer; /* key is in beginning of buffer, we zero-terminated it */
 		val = valbuf;
-		insert_table_str(f_global, buffer, val);
+		if (strcmp(buffer,"LLCONFIGFILE") == 0) {
+		    /* LLCONFIGFILE is not entered in table, only used to 
+		     * chain to another config file
+		     */
+		    *chain = strsave(val);
+		} else {
+		    insert_table_str(f_global, buffer, val);
+		}
 	}
 	failed = !feof(fp);
 	fclose(fp);
 	if (failed) {
 		/* error is in heap */
 		*pmsg = strsave(_(qSopt2long));
-		return FALSE;
+		return -1; /* -1 for error */
 	}
 	free_optable(&f_predef);
 	send_notifications();
-	return TRUE;
+	return 1; /* 1 for ok */
 }
 /*=================================
  * load_global_options -- 
  *  Load internal table of global options from caller-specified config file
  * STRING * pmsg: heap-alloc'd error string if fails
+ * returns 1 for ok, 0 for not found, -1 for error
  *===============================*/
-BOOLEAN
+INT
 load_global_options (STRING configfile, STRING * pmsg)
 {
+	STRING chain = NULL;
+	INT rtn = 0;
+	INT cnt = 0;
 	*pmsg = NULL;
 	if (!f_global) 
 		f_global= create_table_str();
-	if (!load_config_file(configfile, pmsg))
-		return FALSE;
-	return TRUE;
+	do {
+	    if (chain) strfree(&chain);
+	    rtn = load_config_file(configfile, pmsg, &chain);
+	    if (rtn == -1) {
+		if (chain) strfree(&chain);
+		return rtn;
+	    }
+	    if (++cnt > 100) {
+	        return -1;  /* prevent infinite recursion */
+	    }
+	} while (chain);
+
+	return rtn;
 }
 /*=================================
  * set_cmd_options -- Store cmdline options from caller
@@ -285,13 +314,13 @@ term_lloptions (void)
 	remove_listeners(&f_notifications);
 }
 /*===============================================
- * getoptstr -- get an option (from db or from global)
+ * getlloptstr -- get an option (from db or from global)
  * Example: 
- *  str = getoptstr("HDR_SUBM", "1 SUBM");
+ *  str = getlloptstr("HDR_SUBM", "1 SUBM");
  * returns string belonging to table
  *=============================================*/
 STRING
-getoptstr (CNSTRING optname, STRING defval)
+getlloptstr (CNSTRING optname, STRING defval)
 {
 	STRING str = 0;
 	if (!str && f_cmd)
@@ -307,29 +336,29 @@ getoptstr (CNSTRING optname, STRING defval)
 	return str;
 }
 /*===============================================
- * getoptstr_rpt -- get an option (checking report-local options first)
+ * getlloptstr_rpt -- get an option (checking report-local options first)
  * Example: 
- *  str = getoptstr("HDR_SUBM", "1 SUBM");
+ *  str = getlloptstr_rpt("HDR_SUBM", "1 SUBM");
  * Created: 2002/06/16, Perry Rapp
  *=============================================*/
 STRING
-getoptstr_rpt (CNSTRING optname, STRING defval)
+getlloptstr_rpt (CNSTRING optname, STRING defval)
 {
 	STRING str = 0;
 	if (!str && f_rpt)
 		str = valueof_str(f_rpt, optname);
 	if (!str)
-		str = getoptstr(optname, defval);
+		str = getlloptstr(optname, defval);
 	return str;
 }
 /*===============================================
- * getoptstr_dbonly -- get an option (but only look at db options)
+ * getlloptstr_dbonly -- get an option (but only look at db options)
  * Example: 
- *  str = getoptstr_dbonly("codeset", 0);
+ *  str = getlloptstr_dbonly("codeset", 0);
  * Created: 2002/06/16, Perry Rapp
  *=============================================*/
 STRING
-getoptstr_dbonly (CNSTRING optname, STRING defval)
+getlloptstr_dbonly (CNSTRING optname, STRING defval)
 {
 	STRING str = 0;
 	if (f_db)
@@ -339,18 +368,18 @@ getoptstr_dbonly (CNSTRING optname, STRING defval)
 	return str;
 }
 /*===============================================
- * getoptint -- get a numerical option
+ * getlloptint -- get a numerical option
  *  First tries user option table (looks up optname)
  *  Then tries config option table
  *  Finally defaults to defval
  * Example: 
-	if (getoptint("FullReportCallStack", 0) > 0)
+	if (getlloptint("FullReportCallStack", 0) > 0)
  * Created: 2001/11/22, Perry Rapp
  *=============================================*/
 INT
-getoptint (CNSTRING optname, INT defval)
+getlloptint (CNSTRING optname, INT defval)
 {
-	STRING str = getoptstr(optname, 0);
+	STRING str = getlloptstr(optname, 0);
 	return str ? atoi(str) : defval;
 }
 /*===============================================
