@@ -39,7 +39,6 @@
 /* strings used to clear the screen */
 STRING empstr = SS "                                                ";
 STRING empstr71 = SS "                                                                       ";
-STRING empstr120 = SS "                                                                                                                        ";
 
 
 ZST qSiddbse      = N_("You must identify a database.");
@@ -62,7 +61,7 @@ ZST qSronlym      = N_("The database is read only; you may not merge records.");
 ZST qSronlyr      = N_("The database is read only; you may not remove records.");
 ZST qSronly       = N_("The database is read only.");
 
-ZST qSidbrws      = N_("enter name, key, refn or list:");
+ZST qSidbrws      = N_("Name, key, refn, list, or @:");
 ZST qSidkyrfn     = N_("enter key or refn: ");
 ZST qSidcrmv      = N_("Please choose the child to remove from the family.");
 ZST qSidsrmv      = N_("Please choose the spouse/parent to remove from the family.");
@@ -96,11 +95,7 @@ ZST qSidcswp      = N_("Identify a parent in the family having children swapped.
 ZST qSidfswp      = N_("Whose families/spouses are to be swapped?");
 ZST qSidprnt      = N_("Identify one of the child's parents, if known.");
 
-ZST qSscanrs      = N_("Scan results:");
-ZST qSscnnmf      = N_("Enter pattern to match against single surname or given name.");
-ZST qSscnfnm      = N_("Enter pattern to match against full name.");
 ZST qSscnrfn      = N_("Enter pattern to match against refn.");
-ZST qSscantt      = N_("pattern: ");
 
 ZST qSnotonei     = N_("Please choose from among these people.");
 ZST qSnotonex     = N_("Please choose from among these records.");
@@ -273,7 +268,6 @@ ZST qSnosuchtt    = N_("No such translation table in this database");
 ZST qSgdnadd      = N_("Because of errors the GEDCOM file was not loaded.\n");
 ZST qSdboldk      = N_("No errors; adding records with original keys...");
 ZST qSdbnewk      = N_("No errors; adding records with new keys...");
-ZST qSdbodel      = N_("Using original keys, %d deleted records will be in the database.");
 ZST qScfoldk      = N_("Use original keys from GEDCOM file?");
 ZST qSproceed     = N_("Proceed?");
 ZST qSoutarc      = N_("Enter name of output archive file.");
@@ -416,10 +410,6 @@ ZST qStag2lng2cnc = N_("Tag is too long to connect automatically.");
 ZST qSdbrecords   = N_("Database records");
 ZST qSdbrecstats  = N_("%dI, %dF, %dS, %dE, %dX");
 
-/* initialization */
-ZST qSwin2big     = N_("The requested window size (%d,%d) is too large for your terminal (%d,%d).\n");
-ZST qSwin2small   = N_("The requested window size (%d,%d) is too small for LifeLines (%d,%d).\n");
-
 /* menus */
 ZST qSmtitle      = N_("LifeLines %s - Genealogical DB and Programming System");
 ZST qScright      = N_("Copyright(c) 1991 to 1996, by T. T. Wetmore IV");
@@ -445,8 +435,7 @@ ZST qSttlauxbrw   = N_("LifeLines -- Auxiliary Browse Screen (* toggles menu)");
 ZST qSttllstbrw   = N_("LifeLines -- List Browse Screen (* toggles menu)");
 
 /* list menu */
-ZST qSchlist      = N_("Commands:   j Move down     k Move up    i Select     q Quit");
-ZST qSvwlist      = N_("Commands:   j Move down     k Move up    q Quit");
+
 ZST qSchlistx     = N_("Commands:   Select by number, u Page Up, d Page Down, i Select, q Quit");
 ZST qSvwlistx     = N_("Commands:   u Page Up, d Page Down, q Quit");
 ZST qSerrlist     = N_("Messages:");
@@ -470,7 +459,6 @@ ZST qSdataerr     = N_("Error accessing data");
 ZST qSidhist      = N_("Choose from history");
 ZST qSnorwandro   = N_("Cannot combine immutable (-i) or read-only (-r) with read-write (-w) access.");
 ZST qSnofandl     = N_("Cannot combine forceopen (-f) and lock (-l) flags.");
-ZST qSidrpt       = N_("Program");
 ZST qSiddefpath   = N_("Default path: ");
 ZST qSmisskeys    = N_("WARNING: missing keys");
 ZST qSbadkeyptr   = N_("This does not point to another record in the database!");
@@ -562,16 +550,12 @@ ZST qSmn_del_any  = N_("o  Other - remove other record completely");
 
 /* &&end delete menu, begin search menu */
 ZST qSmn_sea_ttl  = N_("How would you like to find a record?");
-ZST qSmn_sea_scan = N_("f  Full database scan");
 
-/* &&end search menu, begin fullscan menu */
-ZST qSmn_sca_ttl  = N_("What scan type?");
-ZST qSmn_sca_nmfu = N_("f  Full name scan");
-ZST qSmn_sca_nmfr = N_("n  Name fragment (whitespace-delimited) scan");
-ZST qSmn_sca_refn = N_("r  Refn scan");
+/* &&end search menu, begin scan status strings */
 ZST qSsts_sca_ful = N_("Performing full name scan");
 ZST qSsts_sca_fra = N_("Performing name fragment scan");
 ZST qSsts_sca_ref = N_("Performing refn scan");
+ZST qSsts_sca_src = N_("Performing source scan");
 ZST qSsts_sca_non = N_("No records found in scan");
 
 /* &&complex date strings (A=abbrev, B=full)*/
