@@ -38,6 +38,7 @@
 #include "mystring.h" /* fi_chrcmp */
 #include "zstr.h"
 
+
 /*********************************************
  * external/imported variables
  *********************************************/
@@ -60,12 +61,12 @@ static void getnamerec(const RKEY * rkey);
 static CNSTRING getsurname_impl(CNSTRING name);
 static STRING name_surfirst(STRING);
 static void name_to_parts(CNSTRING, STRING*);
-static void name2rkey(CNSTRING, RKEY *);
+/* static void name2rkey(CNSTRING, RKEY *); */
 static CNSTRING nextpiece(CNSTRING);
 static STRING parts_to_name(STRING*);
 static BOOLEAN piecematch(STRING, STRING);
 static void remove_namekey(const RKEY * rkeyname, CNSTRING name, const RKEY * rkeyid);
-static void rkey_cpy(const RKEY * src, RKEY * dest);
+/* static void rkey_cpy(const RKEY * src, RKEY * dest);*/
 static BOOLEAN rkey_eq(const RKEY * rkey1, const RKEY * rkey2);
 static void soundex2rkey(char finitial, CNSTRING sdex, RKEY * rkey);
 static void squeeze(CNSTRING, STRING);
@@ -132,7 +133,7 @@ static void
 parsenamerec (const RKEY * rkey, CNSTRING p)
 {
 	INT i;
-	rkey_cpy(rkey, &NRkey);
+	memcpy(&NRkey, rkey, sizeof(*rkey));
 /* Store name record in data structures */
 	memcpy (&NRcount, p, sizeof(INT));
 	ASSERT(NRcount < 1000000); /* 1000000 names in a given slot ? */
@@ -172,9 +173,9 @@ across database reloads
 	if (NRrec && eqrkey(rkey, &NRKEY))
 		return NRcount>0;
 */
-	rkey_cpy(rkey, &NRkey);
+	memcpy(&NRkey, rkey, sizeof(*rkey));
 	strfree(&NRrec);
-	p = NRrec = getrecord(BTR, rkey, &NRsize);
+	p = NRrec = bt_getrecord(BTR, rkey, &NRsize);
 	if (!NRrec) {
 		NRcount = 0;
 		if (NRmax == 0) {
@@ -191,6 +192,7 @@ across database reloads
 /*============================================
  * name2rkey - Convert name to name record key
  *==========================================*/
+/* unused
 static void
 name2rkey (CNSTRING name, RKEY * rkey)
 {
@@ -204,6 +206,7 @@ name2rkey (CNSTRING name, RKEY * rkey)
 	rkey->r_rkey[6] = *sdex++;
 	rkey->r_rkey[7] = *sdex;
 }
+unused */
 /*============================================
  * soundex2rkey - Convert soundex coded name to name record key
  *==========================================*/
@@ -233,8 +236,9 @@ rkey_eq (const RKEY * rkey1, const RKEY * rkey2)
 	return TRUE;
 }
 /*============================================
- * eqrkey - Are two rkeys the same ?
+ * rkey_cpy - copy rkeys from src to dest?
  *==========================================*/
+/* unused 
 static void
 rkey_cpy (const RKEY * src, RKEY * dest)
 {
@@ -244,6 +248,7 @@ rkey_cpy (const RKEY * src, RKEY * dest)
 		dest->r_rkey[i] = src->r_rkey[i];
 	}
 }
+unused */
 /*=======================================
  * name_lo - Lower limit for name records
  *=====================================*/
@@ -360,14 +365,14 @@ getfinitial (CNSTRING name)
  *  key:   [in] person's INDI key
  *=======================================*/
 void
-add_name (STRING name, STRING key)
+add_name (CNSTRING name, CNSTRING key)
 {
 	INT i;
 	RKEY rkeyid = str2rkey(key);
 	RKEY rkeyname;
 	char finitial = getfinitial(name);
 	STRING surname = strsave(getsxsurname(name));
-	TABLE donetab = create_table(FREEKEY);
+	TABLE donetab = create_table_int();
 	STRING rkeystr=0;
 
 	for (i=0; i<soundex_count(); ++i) 	{
@@ -375,7 +380,7 @@ add_name (STRING name, STRING key)
 		soundex2rkey(finitial, sdex, &rkeyname);
 		/* rkeyname is where names with this soundex/finitial are stored */
 		/* check if we've already done this entry */
-		rkeystr = strsave(rkey2str(rkeyname));
+		rkeystr = rkey2str(rkeyname);
 		if (dupcheck(donetab, rkeystr)) {
 			strfree(&rkeystr);
 			continue;
@@ -434,7 +439,7 @@ add_namekey (const RKEY * rkeyname, CNSTRING name, const RKEY * rkeyid)
 		p += strlen(NRnames[i]) + 1;
 		len += strlen(NRnames[i]) + 1;
 	}
-	addrecord(BTR, NRkey, rec, len);
+	bt_addrecord(BTR, NRkey, rec, len);
 	stdfree(rec);
 
 	/* NRnames[NRcount] doesn't point into record */
@@ -446,14 +451,14 @@ add_namekey (const RKEY * rkeyname, CNSTRING name, const RKEY * rkeyid)
  *  key:  [in] person's INDI key
  *===========================================*/
 void
-remove_name (STRING name, STRING key)
+remove_name (STRING name, CNSTRING key)
 {
 	INT i;
 	RKEY rkeyid = str2rkey(key);
 	RKEY rkeyname;
 	char finitial = getfinitial(name);
 	STRING surname = strsave(getsxsurname(name));
-	TABLE donetab = create_table(FREEKEY);
+	TABLE donetab = create_table_int();
 	STRING rkeystr=0;
 
 	for (i=0; i<soundex_count(); ++i) 	{
@@ -525,7 +530,7 @@ remove_namekey (const RKEY * rkeyname, CNSTRING name, const RKEY * rkeyid)
 		p += strlen(NRnames[i]) + 1;
 		len += strlen(NRnames[i]) + 1;
 	}
-	addrecord(BTR, NRkey, rec, len);
+	bt_addrecord(BTR, NRkey, rec, len);
 	stdfree(rec);
 }
 /*=========================================================
@@ -630,7 +635,7 @@ find_indis_by_name (CNSTRING name)
 	RECORD rec;
 	uchar finitial = getfinitial(name);
 	STRING surname = strsave(getsxsurname(name));
-	TABLE donetab = create_table(FREEKEY);
+	TABLE donetab = create_table_int();
 	LIST list = create_list2(LISTDOFREE);
 
 	/* See if user is asking for person by key instead of name */
@@ -717,9 +722,9 @@ find_indis_worker (CNSTRING name, uchar finitial, CNSTRING sdex, TABLE donetab,
 static BOOLEAN
 dupcheck (TABLE tab, CNSTRING str)
 {
-	if (valueof_str(tab, str))
+	if (in_table(tab, str))
 		return TRUE;
-	insert_table_str(tab, strsave(str), 0);
+	insert_table_int(tab, str, 1);
 	return FALSE;
 }
 /*====================================
@@ -1020,6 +1025,7 @@ name_surfirst (STRING name)
  *  name:  [IN]  name to search for
  *  ctype: [IN]  type of record (eg, 'I') (0 for any)
  * returns record found, or NULL
+ * returns addref'd record
  *==============================*/
 RECORD
 id_by_key (CNSTRING name, char ctype)
@@ -1078,20 +1084,21 @@ id_by_key (CNSTRING name, char ctype)
 /*============================================
  * name_to_list -- Convert name to string list
  *  name:  [IN]  GEDCOM name
- *  list:  [I/O] list (must exist)
  *  plen:  [OUT]  returned length
  *  psind: [OUT]  index (rel 1) of surname in list
  * Returns a list whose elements are strings
  *==========================================*/
-BOOLEAN
-name_to_list (CNSTRING name, LIST list, INT *plen, INT *psind)
+LIST
+name_to_list (CNSTRING name, INT *plen, INT *psind)
 {
 	INT i;
 	STRING str;
 	STRING parts[MAXPARTS];
-	if (!name || *name == 0 || !list) return FALSE;
-	make_list_empty(list);
-	set_list_type(list, LISTDOFREE);
+	LIST list = create_list2(LISTDOFREE);
+
+	if (!name || *name == 0)
+		return list;
+
 	*psind = 0;
 	name_to_parts(name, parts);
 	for (i = 0; i < MAXPARTS; i++) {
@@ -1106,32 +1113,7 @@ name_to_list (CNSTRING name, LIST list, INT *plen, INT *psind)
 		set_list_element(list, i + 1, str, NULL);
 	}
 	*plen = i;
-	return TRUE;
-}
-/*====================================================
- * free_string_el -- free alloc'd string element of list
- *==================================================*/
-static void
-free_string_el(VPTR w)
-{
-	stdfree((STRING)w);
-}
-/*====================================================
- * free_name_list -- Free list created by name_to_list
- *==================================================*/
-void
-free_name_list (LIST list)
-{
-	/* name list is just string list */
-	free_string_list(list);
-}
-/*====================================================
- * free_string_list -- free list of alloc'd strings
- *==================================================*/
-void
-free_string_list(LIST list)
-{
-	remove_list(list, free_string_el);
+	return list;
 }
 /*====================================================
  * traverse_names -- traverse names in db
@@ -1142,12 +1124,12 @@ free_string_list(LIST list)
  *==================================================*/
 typedef struct
 {
-	BOOLEAN(*func)(STRING key, CNSTRING name, BOOLEAN newset, void *param);
+	BOOLEAN(*func)(CNSTRING key, CNSTRING name, BOOLEAN newset, void *param);
 	void * param;
 } TRAV_NAME_PARAM;
 /* see above */
 static BOOLEAN
-traverse_name_callback (RKEY rkey, CNSTRING data, INT len, void *param)
+traverse_name_callback (RKEY rkey, STRING data, INT len, void *param)
 {
 	TRAV_NAME_PARAM *tparam = (TRAV_NAME_PARAM *)param;
 	INT i;
@@ -1164,7 +1146,7 @@ traverse_name_callback (RKEY rkey, CNSTRING data, INT len, void *param)
 }
 /* see above */
 void
-traverse_names (BOOLEAN(*func)(STRING key, CNSTRING name, BOOLEAN newset, void *param), void *param)
+traverse_names (BOOLEAN(*func)(CNSTRING key, CNSTRING name, BOOLEAN newset, void *param), void *param)
 {
 	TRAV_NAME_PARAM tparam;
 	tparam.param = param;
