@@ -134,7 +134,7 @@ init_valtab_from_string (CNSTRING str, TABLE tab, INT sep, STRING *pmsg)
 		while ((c = *q++ = *p++) && c != sep && c != '\n')
 			;
 		if (c == 0 || c =='\n') {
-			sprintf(errmsg, "line %d: no value", n);
+			sprintf(errmsg, "line %ld: no value", n);
 			*pmsg = errmsg;
 			goto endinitvaltab;
 		}
