@@ -50,6 +50,21 @@ extern BTREE BTR;
  * nixrefs==1 means there are no deleted INDI keys
  * nixrefs==2 means there is one deleted INDI key (ixrefs[1])
  *=================================================================*/
+/*
+ In memory, data is kept in a DELETESET
+ A brand new DELETE set has
+   n = 1 (0 deleted records)
+   recs[0] = 1 (recs[0] is always next available record above highest in use)
+   max = basic allocation unit (currently 64)
+   ctype varies (eg, 'I' for the INDI set)
+ If there are I1-I4 and I6 are live in the database, and I5 was deleted,
+ then the DELETE set has
+  n = 2 (1 deleted record)
+  recs[0] = 6 (next available record above highest in use)
+  recs[1] = 5 (I5 was deleted, so it is available)
+  max = allocation unit (still 64)
+  ctype as above (eg, 'I' for the INDI set)
+*/
 
 /*********************************************
  * local types
@@ -77,7 +92,12 @@ typedef struct deleteset_s *DELETESET;
  *********************************************/
 
 /* alphabetical */
+static BOOLEAN addixref_impl(INT key, DUPS dups);
+static BOOLEAN addfxref_impl(INT key, DUPS dups);
+static BOOLEAN addsxref_impl(INT key, DUPS dups);
+static BOOLEAN addexref_impl(INT key, DUPS dups);
 static BOOLEAN addxref_impl(CNSTRING key, DUPS dups);
+static BOOLEAN addxxref_impl(INT key, DUPS dups);
 static INT find_slot(INT keynum, DELETESET set);
 static void freexref(DELETESET set);
 static DELETESET get_deleteset_from_type(char ctype);
@@ -85,14 +105,11 @@ static STRING getxref(DELETESET set);
 static void growxrefs(DELETESET set);
 static STRING newxref(STRING xrefp, BOOLEAN flag, DELETESET set);
 static INT num_set(DELETESET set);
+static BOOLEAN parse_key(CNSTRING key, char * ktype, INT * kval);
 static void readrecs(DELETESET set);
 static BOOLEAN readxrefs(void);
+static BOOLEAN xref_isvalid_impl(DELETESET set, INT keynum);
 static INT xref_last(DELETESET set);
-static BOOLEAN addixref_impl(INT key, DUPS dups);
-static BOOLEAN addfxref_impl(INT key, DUPS dups);
-static BOOLEAN addsxref_impl(INT key, DUPS dups);
-static BOOLEAN addexref_impl(INT key, DUPS dups);
-static BOOLEAN addxxref_impl(INT key, DUPS dups);
 
 /*********************************************
  * local variables
@@ -198,8 +215,20 @@ static INT
 getxrefnum (DELETESET set)
 {
 	INT keynum;
-	ASSERT(xreffp && set->n >= 1);
-	keynum = (set->n == 1) ? set->recs[0]++ : set->recs[--(set->n)];
+	ASSERT(xreffp);
+	ASSERT(set->n >= 1);
+	if (set->n == 1) {
+		/* no free records on list */
+		/* take new high number & bump high number */
+		keynum = set->recs[0]++;
+	} else {
+		/* take last free record on list */
+		keynum = set->recs[set->n - 1];
+		/* zero out the entry slipping off the top of the list */
+		set->recs[set->n - 1] = 0;
+		/* remove just-used entry from list */
+		--(set->n);
+	}
 	ASSERT(writexrefs());
 	maxkeynum=-1;
 	return keynum;
@@ -215,7 +244,7 @@ getxref (DELETESET set)
 {
 	INT keynum = getxrefnum(set);
 	static char scratch[12];
-	sprintf(scratch, "@%c%d@", set->ctype, keynum);
+	sprintf(scratch, "@%c%ld@", set->ctype, keynum);
 	return scratch;
 }
 /*===================================================
@@ -365,18 +394,35 @@ static BOOLEAN
 add_xref_to_set_impl (INT keynum, DELETESET set, DUPS dups)
 {
 	INT lo, i;
-	if (keynum <= 0 || !xreffp || (set->n) < 1) FATAL();
+	if (keynum <= 0 || !xreffp || (set->n) < 1) {
+		char msg[128];
+		snprintf(msg, sizeof(msg)/sizeof(msg[0])
+			, _("Corrupt DELETESET %c"), set->ctype);
+		FATAL2(msg);
+	}
+	/* special case simplification if deleting last record */
+	if (keynum+1 == set->recs[0]) {
+		/*
+		just bump the 'next free' indicator down to 
+		return this keynum next, and we don't even have to
+		add this to the list
+		*/
+		--set->recs[0];
+		ASSERT(writexrefs());
+		return TRUE;
+	}
 	if (set->n >= set->max)
 		growxrefs(set);
 	ASSERT(set->n < set->max);
 
 	lo = find_slot(keynum, set);
-	if ((set->recs)[lo] == keynum) {
+	if (lo < set->n && (set->recs)[lo] == keynum) {
 		/* key is already free */
 		char msg[96];
 		if (dups==DUPSOK) 
 			return FALSE;
-		sprintf(msg, "Tried to add already-deleted record (%d) to xref (%c)!"
+		snprintf(msg, sizeof(msg)/sizeof(msg[0])
+			, _("Tried to add already-deleted record (%ld) to xref (%c)!")
 			, keynum, set->ctype);
 		FATAL2(msg); /* deleting a deleted record! */
 	}
@@ -415,13 +461,19 @@ void addxxref (INT key) { addxxref_impl(key, NODUPS); }
 static BOOLEAN
 addxref_impl (CNSTRING key, DUPS dups)
 {
-	INT keyint = atoi(key + 1);
-	switch(key[0]) {
-	case 'I': return addixref_impl(keyint, dups);
-	case 'F': return addfxref_impl(keyint, dups);
-	case 'S': return addsxref_impl(keyint, dups);
-	case 'E': return addexref_impl(keyint, dups);
-	case 'X': return addxxref_impl(keyint, dups);
+	char ktype=0;
+	INT keynum=0;
+	if (!parse_key(key, &ktype, &keynum)) {
+		char msg[512];
+		snprintf(msg, sizeof(msg)/sizeof(msg[0]), "Bad key passed to addxref_impl: %s", key);
+		FATAL2(msg);
+	}
+	switch(ktype) {
+	case 'I': return addixref_impl(keynum, dups);
+	case 'F': return addfxref_impl(keynum, dups);
+	case 'S': return addsxref_impl(keynum, dups);
+	case 'E': return addexref_impl(keynum, dups);
+	case 'X': return addxxref_impl(keynum, dups);
 	default: ASSERT(0); return FALSE;
 	}
 }
@@ -489,22 +541,71 @@ delete_xref_if_present (CNSTRING key)
 	INT lo=0;
 	INT i=0;
 
-	ASSERT(key && key[0] && key[1]);
+	ASSERT(key);
+	ASSERT(key[0]);
+	ASSERT(key[1]);
 	set = get_deleteset_from_type(key[0]);
 	keynum = atoi(key + 1);
 	ASSERT(keynum>0);
 	lo = find_slot(keynum, set);
-	if ((set->recs)[lo] != keynum)
+	if (!(lo < set->n && (set->recs)[lo] == keynum))
 		return FALSE;
 	/* removing xrefs[lo] -- move lo+ down */
 	for (i=lo; i+1<set->n-1; ++i)
 		(set->recs)[i] = (set->recs)[i+1];
+	/* zero out the entry slipping off the top of the list */
+	if (set->n > 1)
+		set->recs[set->n - 1] = 0;
 	--(set->n);
 	ASSERT(writexrefs());
 	maxkeynum=-1;
 	return TRUE;
 
 }
+/*==========================================
+ * parse_key -- Get key type (first char) and numeric value
+ * parse_key("I44") => 'I', 44
+ *========================================*/
+static BOOLEAN
+parse_key (CNSTRING key, char * ktype, INT * kval)
+{
+	if (!key || !key[0] || !key[1])
+		return FALSE;
+	/* convert "@I44@" to "I44" */
+	if (key[0] == '@' && key[strlen(key)-1] == '@')
+		key = rmvat(key);
+	*ktype = key[0];
+	*kval = atoi(key+1);
+	return TRUE;
+}
+/*==========================================
+ * is_key_in_use -- Return TRUE if a live record
+ *========================================*/
+BOOLEAN
+is_key_in_use (CNSTRING key)
+{
+	DELETESET set=0;
+	INT keynum=0;
+	char ktype=0;
+	CNSTRING barekey=0;
+	BOOLEAN result=FALSE;
+
+	if (!parse_key(key, &ktype, &keynum)) {
+		char msg[512];
+		snprintf(msg, sizeof(msg)/sizeof(msg[0]), "Bad key passed to is_key_in_use: %s", key);
+		FATAL2(msg);
+	}
+
+	set = get_deleteset_from_type(ktype);
+
+	ASSERT(keynum>0);
+	
+	result = xref_isvalid_impl(set, keynum);
+
+	strfree((STRING *)&barekey);
+	
+	return result;
+}
 /*==========================================
  * freexref -- Free memory & clear xrefs array
  *  Called when database is closed
@@ -753,29 +854,43 @@ INT xref_lastx (void) { return xref_last(&xrecs); }
  * xrefs_get_counts_from_unopened_db --
  *  read record counts out of file on disk
  * returns FALSE if specified path is not the root of a traditional lifelines database
+ * If db structure error, errptr points to description of error (in static buffer)
  *=====================================*/
 BOOLEAN
 xrefs_get_counts_from_unopened_db (CNSTRING path, INT *nindis, INT *nfams
-	, INT *nsours, INT *nevens, INT *nothrs)
+	, INT *nsours, INT *nevens, INT *nothrs, char ** errptr)
 {
 	char scratch[100];
+	static char errstr[256];
 	FILE * fp = 0;
 	INT i;
 	INT ndels[5], nmax[5];
 
+	*errptr = 0;
+
 	ASSERT(!xreffp);
 	sprintf(scratch, "%s/xrefs", path);
 	if (!(fp = fopen(scratch, LLREADBINARY))) {
 		return FALSE;
 	}
 	for (i=0; i<5; ++i) {
-		ASSERT(fread(&ndels[i], sizeof(INT), 1, fp) == 1);
+		if (fread(&ndels[i], sizeof(INT), 1, fp) != 1) {
+			snprintf(errstr, sizeof(errstr), "ndels[%ld] bad", i);
+			*errptr = errstr;
+			fclose(fp);
+			return FALSE;
+		}
 	}
 	for (i=0; i<5; ++i) {
 		INT j;
 		for (j=0; j<ndels[i]; ++j) {
 			INT k;
-			ASSERT(fread(&k, sizeof(INT), 1, fp) == 1);
+			if (fread(&k, sizeof(INT), 1, fp) != 1) {
+				snprintf(errstr, sizeof(errstr), "ndels[%ld]#%ld bad", i, j);
+				*errptr = errstr;
+				fclose(fp);
+				return FALSE;
+			}
 			if (!j)
 				nmax[i] = k;
 		}
