@@ -29,46 +29,36 @@
 #ifndef _DATE_H
 #define _DATE_H
 
-
-/* GEDCOM dates */
 enum { BAD_YEAR=-99999 };
-struct tag_dnum { INT val; INT val2; STRING str; };
-struct tag_gdate {
-	INT calendar;
-	struct tag_dnum year;
-	struct tag_dnum month;
-	struct tag_dnum day;
-	INT mod;
-	INT eratime; /* eg, AD, BC */
+struct tag_dnum {
+	INT val;    /* parsed value, eg, 2 for FEBRUARY */
+	INT val2;   /* TODO: need comment explaining what this is */
+	STRING str; /* raw string that was in date */
 };
-struct tag_gdateval {
-	struct tag_gdate date1;
-	struct tag_gdate date2; /* used by period/from_to & range/bet_and */
-	INT type;
-	INT subtype;
-	INT valid; /* -1=bad syntax, 0=freeform, 1=perfect GEDCOM date */
-	STRING text; /* copy of original */
-};
-typedef struct tag_gdateval *GDATEVAL;
-enum { GDV_PERIOD=1, GDV_RANGE, GDV_DATE, GDV_APPROX  };
-enum { GDVP_FROM=1, GDVP_TO, GDVP_FROM_TO }; /* period subtype */
-enum { GDVR_BEF=1, GDVR_AFT, GDVR_BET, GDVR_BET_AND }; /* range subtype */
-enum { GDVA_ABT=1, GDVA_EST, GDVA_CAL }; /* approx subtype */
-enum { GDV_GREGORIAN=1, GDV_JULIAN, GDV_HEBREW, GDV_FRENCH, GDV_ROMAN, GDV_CALENDARS_IX };
-enum { GDV_AD=1, GDV_BC };
+
+typedef struct tag_gdateval *GDATEVAL; /* definition of struct in datei.h */
 
 ZSTR approx_time(INT seconds);
 GDATEVAL create_gdateval(void);
 STRING do_format_date(STRING, INT, INT, INT, INT, INT, INT);
 void date_update_lang(void);
+INT date_get_day(GDATEVAL gdv);
+INT date_get_mod(GDATEVAL gdv);
+INT date_get_month(GDATEVAL gdv);
+INT date_get_year(GDATEVAL gdv);
+STRING date_get_year_string(GDATEVAL gdv);
 GDATEVAL extract_date(STRING);
 void free_gdateval(GDATEVAL gdv);
 BOOLEAN gdateval_isdual(GDATEVAL);
 STRING get_todays_date(void);
+BOOLEAN is_valid_dayfmt(INT dayfmt);
+BOOLEAN is_valid_monthfmt(INT monthfmt);
+BOOLEAN is_valid_yearfmt(INT yearfmt);
 BOOLEAN set_cmplx_pic(INT ecmplx, STRING pic);
 void set_date_pic(STRING pic);
 STRING shorten_date(STRING);
 void term_date(void);
 
 
+
 #endif /* _DATE_H */
