@@ -93,6 +93,7 @@ struct tag_node {
 #define nsibling(n) ((n)->n_sibling)
 #define nflag(n)    ((n)->n_flag)
 #define nrefcnt(n)  ((n)->n_refcnt)
+#define ncel(n)     ((n)->n_cel)
 enum { ND_TEMP=1 };
 
 struct tag_nkey { char ntype; INT keynum; char key[MAXKEYWIDTH+1]; };
@@ -230,7 +231,7 @@ NODE convert_first_fp_to_node(FILE*, BOOLEAN, XLAT, STRING*, BOOLEAN*);
 NODE copy_node(NODE);
 NODE copy_node_subtree(NODE node);
 NODE copy_nodes(NODE node, BOOLEAN kids, BOOLEAN sibs);
-BOOLEAN create_database(STRING dbused);
+BOOLEAN create_database(STRING dbused, INT *lldberr);
 NODE create_node(STRING, STRING, STRING, NODE);
 NODE create_temp_node(STRING, STRING, STRING, NODE);
 void delete_metarec(STRING key);
@@ -388,7 +389,7 @@ INT num_indis(void);
 INT num_spouses_of_indi(NODE);
 INT num_sours(void);
 INT num_othrs(void);
-BOOLEAN open_database(INT alteration, STRING dbused);
+BOOLEAN open_database(INT alteration, STRING dbused, INT *lldberr);
 BOOLEAN openxref(BOOLEAN readonly);
 STRING other_to_list_string(NODE node, INT len, STRING delim);
 void othr_to_cache(NODE);
@@ -433,8 +434,8 @@ INT resolve_refn_links(NODE);
 RECORD_STATUS retrieve_to_file(STRING key, STRING file);
 RECORD_STATUS retrieve_to_textfile(STRING key, STRING file, TRANSLFNC);
 STRING retrieve_raw_record(CNSTRING, INT*);
-STRING rmvat(STRING);
-STRING rmvbrackets(STRING str);
+STRING rmvat(CNSTRING);
+STRING rmvbrackets(CNSTRING str);
 STRING rpt_setlocale(STRING str);
 void rptlocale(void);
 void save_original_locales(void);
@@ -499,14 +500,19 @@ STRING generic_to_list_string(NODE node, STRING key, INT len, STRING delim, RFMT
 STRING *get_child_strings(NODE, RFMT, INT*, STRING**);
 STRING indi_to_list_string(NODE indi, NODE fam, INT len, RFMT rfmt, BOOLEAN appkey);
 
+/* init.c */
+void print_version(CNSTRING program);
+
 /* lldatabase.c */
 LLDATABASE lldb_alloc(void);
 void lldb_close(LLDATABASE *plldb);
 void lldb_set_btree(LLDATABASE lldb, void * btree);
 
 /* llgettext.c */
-void set_gettext_codeset(CNSTRING domain, CNSTRING codeset);
 CNSTRING get_gettext_codeset(void);
+void ll_bindtextdomain(CNSTRING domain, CNSTRING localeDir);
+void llgettext_set_default_localedir(CNSTRING defLocaleDir);
+void set_gettext_codeset(CNSTRING domain, CNSTRING codeset);
 
 /* misc.c */
 INT xrefval(char ntype, STRING str);
@@ -544,6 +550,9 @@ void nodechk(NODE node, CNSTRING scope);
 void nodechk_enable(BOOLEAN enable);
 
 /* nodeio.c */
+void prefix_file_for_edit(FILE *fp);
+void prefix_file_for_gedcom(FILE *fp);
+void prefix_file_for_report(FILE *fp);
 STRING node_to_string(NODE);
 NODE string_to_node(STRING);
 void write_indi_to_file_for_edit(NODE indi, CNSTRING file, RFMT rfmt);
@@ -565,6 +574,7 @@ CNSTRING soundex_get(INT i, CNSTRING name);
 /* xreffile.c */
 BOOLEAN addxref_if_missing (CNSTRING key);
 BOOLEAN delete_xref_if_present(CNSTRING key);
+BOOLEAN is_key_in_use(CNSTRING key);
 INT xref_firste(void);
 INT xref_firstf(void);
 INT xref_firsti(void);
