@@ -32,7 +32,11 @@
 #include "list.h"       /* for LIST */
 #include "cache.h"      /* for CACHEEL */
 #include "gedcom.h"     /* for NODE, RECORD */
+
+#ifndef _INDISEQ_H
 #include "indiseq.h"    /* for INDISEQ */
+#endif
+
 #include "table.h"      /* for TABLE */
 
 typedef union {
@@ -127,6 +131,7 @@ PVALUE create_pvalue_from_othr_keynum(INT i);
 PVALUE create_pvalue_from_seq(INDISEQ seq);
 PVALUE create_pvalue_from_sour_keynum(INT i);
 PVALUE create_pvalue_from_string(CNSTRING str);
+PVALUE create_pvalue_from_zstr(ZSTR * pzstr);
 PVALUE create_pvalue_from_table(TABLE tab);
 ZSTR describe_pvalue(PVALUE);
 void delete_vptr_pvalue(VPTR ptr);
@@ -135,6 +140,7 @@ void delete_pvalue_ptr(PVALUE * valp);
 NODE remove_node_and_delete_pvalue(PVALUE *);
 void eq_conform_pvalues(PVALUE, PVALUE, BOOLEAN*);
 BOOLEAN eqv_pvalues(VPTR, VPTR);
+BOOLEAN is_node_pvalue(PVALUE value);
 BOOLEAN is_numeric_pvalue(PVALUE);
 BOOLEAN is_pvalue(PVALUE);
 BOOLEAN is_record_pvalue(PVALUE);
