@@ -29,7 +29,11 @@
  *===========================================================*/
 
 #include "llstdlib.h"
+
+#ifndef _INDISEQ_H
 #include "indiseq.h"
+#endif
+
 #include "feedback.h"
 
 /* Prototypes */
@@ -63,3 +67,5 @@ void refresh_stdout (void);
 void rpt_print (STRING str);
 void view_array (STRING ttl, INT no, STRING *pstrngs);
 BOOLEAN yes_no_value(INT c);
+INDISEQ invoke_search_menu (void);
+
