@@ -1,4 +1,4 @@
-/* curses.h - formerly mycurses.h */
+/* curses.h */
 /* header for windows implementation of curses library */
 
 #ifndef CURSES_H
@@ -62,6 +62,7 @@ int box(WINDOW *wp, chtype x, chtype y);
 int cbreak();
 int clearok(WINDOW *wp, int okay);
 int crmode();
+int curs_set(int mode);
 int delwin(WINDOW *wp);
 int doupdate(void);
 int echo();
