@@ -46,6 +46,7 @@
 #include "zstr.h"
 #include "icvt.h"
 #include "date.h"
+#include "xlat.h"
 
 #ifndef INCLUDED_STDARG_H
 #include <stdarg.h>
@@ -77,9 +78,9 @@ BOOLEAN rpt_cancelled = FALSE;
  * external/imported variables
  *********************************************/
 
-extern BOOLEAN progrunning, progparsing;
 extern INT progerror;
-extern STRING qSwhatrpt,qSidrpt;
+extern BOOLEAN progrunning, progparsing;
+extern STRING qSwhatrpt;
 extern STRING nonint1, nonintx, nonstr1, nonstrx, nullarg1, nonfname1;
 extern STRING nonnodstr1, nonind1, nonindx, nonfam1, nonfamx;
 extern STRING nonrecx, nonnod1;
@@ -92,8 +93,7 @@ extern STRING qSunsupuniv;
  *********************************************/
 
 static STRING check_rpt_requires(PACTX pactx, STRING fname);
-static void disp_symtab(STRING title, SYMTAB stab);
-static BOOLEAN disp_symtab_cb(STRING key, PVALUE val, VPTR param);
+static void clean_orphaned_rptlocks(void);
 static void enqueue_parse_error(const char * fmt, ...);
 static BOOLEAN find_program(STRING fname, STRING localdir, STRING *pfull,BOOLEAN include);
 static void init_pactx(PACTX pactx);
@@ -102,17 +102,13 @@ static void parse_file(PACTX pactx, STRING fname, STRING fullpath);
 static void print_report_duration(INT duration, INT uiduration);
 static void progmessage(MSG_LEVEL level, STRING);
 static void remove_tables(PACTX pactx);
-static STRING vprog_error(PNODE node, STRING fmt, va_list args);
 static void wipe_pactx(PACTX pactx);
 
 /*********************************************
  * local variables
  *********************************************/
 
-static INT dbg_mode = 0;
 static LIST outstanding_parse_errors = 0;
-static char vprog_prevfile[MAXPATHLEN]="";
-static INT vprog_prevline=-1;
 
 /*********************************************
  * local function definitions
@@ -130,9 +126,6 @@ initinterp (void)
 	Perrors = 0;
 	rpt_cancelled = FALSE;
 	explicitvars = FALSE;
-	/* clear previous information */
-	vprog_prevfile[0] = 0;
-	vprog_prevline=-1;
 }
 /*==================================+
  * finishinterp -- Finish interpreter
@@ -142,6 +135,9 @@ finishinterp (void)
 {
 	finishrassa();
 
+	/* clean up any orphaned report locks on records */
+	clean_orphaned_rptlocks();
+
 	if (progerror) {
 		refresh_stdout();
 		/* we used to sleep for 5 seconds here */
@@ -161,22 +157,18 @@ progmessage (MSG_LEVEL level, STRING msg)
 	INT mylen=sizeof(buf);
 	INT maxwidth = msg_width();
 	INT msglen = strlen(msg);
-	STRING program = _(qSidrpt);
 	if (maxwidth >= 0 && maxwidth < mylen)
 		mylen = maxwidth;
 	if (cur_pathinfo && *cur_pathinfo->fullpath && msglen+20 < maxwidth) {
 		INT len = 99999;
 		if (msg_width() >= 0) {
-			len = sizeof(buf)-strlen(program)-1-1-msglen;
+			len = sizeof(buf)-3-msglen;
 		}
-		llstrcatn(&ptr, program, &mylen);
-		llstrcatn(&ptr, " ", &mylen);
-		llstrcatn(&ptr, compress_path(cur_pathinfo->fullpath, len), &mylen);
-		llstrcatn(&ptr, " ", &mylen);
 		llstrcatn(&ptr, msg, &mylen);
+		llstrcatn(&ptr, " [", &mylen);
+		llstrcatn(&ptr, compress_path(cur_pathinfo->fullpath, len), &mylen);
+		llstrcatn(&ptr, "] ", &mylen);
 	} else {
-		llstrcatn(&ptr, program, &mylen);
-		llstrcatn(&ptr, " ", &mylen);
 		llstrcatn(&ptr, msg, &mylen);
 	}
 	msg_output(level, buf);
@@ -283,7 +275,7 @@ interp_program_list (STRING proc, INT nargs, VPTR *args, LIST lifiles
 	/* (paths are resolved before files are enqueued, & stored in pathinfo) */
 
 	gproctab = create_table_obj();
-	globtab = create_symtab();
+	globtab = create_symtab_global();
 	gfunctab = create_table_obj();
 	initinterp();
 
@@ -321,14 +313,14 @@ interp_program_list (STRING proc, INT nargs, VPTR *args, LIST lifiles
 	}
 
 	if (Perrors) {
-		progmessage(MSG_ERROR, _("contains errors.\n"));
+		progmessage(MSG_ERROR, _("Program contains errors.\n"));
 		goto interp_program_exit;
 	}
 
    /* Find top procedure */
 
 	if (!(first = (PNODE) valueof_ptr(get_rptinfo(rootfilepath)->proctab, proc))) {
-		progmessage(MSG_ERROR, _("needs a starting procedure.\n"));
+		progmessage(MSG_ERROR, _("Program needs a starting procedure.\n"));
 		goto interp_program_exit;
 	}
 
@@ -349,7 +341,7 @@ interp_program_list (STRING proc, INT nargs, VPTR *args, LIST lifiles
 			proc, num_params(parm), nargs);
 		goto interp_program_exit;
 	}
-	stab = create_symtab();
+	stab = create_symtab_proc(proc, NULL);
 	for (i = 0; i < nargs; i++) {
 		insert_symtab(stab, iident(parm), args[0]);
 		parm = inext(parm);
@@ -360,7 +352,7 @@ interp_program_list (STRING proc, INT nargs, VPTR *args, LIST lifiles
 	progparsing = FALSE;
 	progrunning = TRUE;
 	progerror = 0;
-	progmessage(MSG_STATUS, _("is running..."));
+	progmessage(MSG_STATUS, _("Program is running..."));
 	ranit = interpret_prog((PNODE) ibody(first), stab);
 
    /* Clean up and return */
@@ -383,6 +375,7 @@ interp_program_notfound:
 	symbol_tables_end();
 	pvalues_end();
 	wipe_pactx(pactx);
+	xl_free_adhoc_xlats();
 
 	/* kill any orphaned pathinfos */
 	while (!is_empty_list(plist)) {
@@ -414,13 +407,13 @@ interpret_prog (PNODE begin, SYMTAB stab)
 	switch(rtn) {
 	case INTOKAY:
 	case INTRETURN:
-		progmessage(MSG_INFO, _("was run successfully.\n"));
+		progmessage(MSG_INFO, _("Program was run successfully.\n"));
 		return TRUE;
 	default:
 		if (rpt_cancelled) {
-			progmessage(MSG_STATUS, _("was cancelled.\n"));
+			progmessage(MSG_STATUS, _("Program was cancelled.\n"));
 		} else
-			progmessage(MSG_STATUS, _("was not run because of errors.\n"));
+			progmessage(MSG_STATUS, _("Program was not run because of errors.\n"));
 		return FALSE;
 	}
 }
@@ -565,7 +558,7 @@ interp_main (LIST lifiles, STRING ofile, BOOLEAN picklist, BOOLEAN timing)
 	(in case first time or uilocale changed) */
 	interp_load_lang();
 	prog_trace = FALSE; /* clear report debug flag */
-	dbg_mode = 0;
+	init_debugger();
 	rptui_init(); /* clear ui time counter */
 
 	rptlocale();
@@ -1788,7 +1781,7 @@ interp_call (PNODE node, SYMTAB stab, PVALUE *pval)
 		irc = INTERROR;
 		goto call_leave;
 	}
-	newstab = create_symtab();
+	newstab = create_symtab_proc(procname, stab);
 	arg = (PNODE) iargs(node);
 	parm = (PNODE) iargs(proc);
 	while (arg && parm) {
@@ -1887,213 +1880,6 @@ traverse_leave:
 	val=NULL;
 	return irc;
 }
-/*=============================================+
- * prog_var_error -- Report a run time program error
- *  due to mistyping of a particular variable
- *  node:  [IN]  current parse node
- *  stab:  [IN]  current symbol table (lexical scope)
- *  arg:   [IN]  if non-null, parse node of troublesome argument
- *  val:   [IN]  if non-null, PVALUE of troublesome argument
- *  fmt... [IN]  message
- * See vprog_error
- * Created: 2002/02/17, Perry Rapp
- *============================================*/
-struct dbgsymtab_s
-{
-	STRING * locals;
-	INT count;
-	INT current;
-};
-void
-prog_var_error (PNODE node, SYMTAB stab, PNODE arg, PVALUE val, STRING fmt, ...)
-{
-	STRING choices[4];
-	INT rtn;
-	va_list args;
-	ZSTR zstr;
-
-	arg = arg; /* unused */
-	/* TODO: What to do with arg ? Perry, 2003-01-19 */
-
-	va_start(args, fmt);
-	zstr = zs_newvf(fmt, args);
-	va_end(args);
-	if (val) {
-		ZSTR zval = describe_pvalue(val);
-		zs_appf(zstr, " (value: %s)", zs_str(zval));
-	}
-	prog_error(node, zs_str(zstr));
-	zs_free(&zstr);
-
-	if (dbg_mode != -99 && dbg_mode != 3) {
-		INT ch = 0;
-		while (!(ch=='d' || ch=='q'))
-			ch = rptui_prompt_stdout(_("Enter d for debugger, q to quit"));
-		if (ch == 'q')
-			dbg_mode = -99;
-	}
-
-	if (dbg_mode != -99) {
-		ZSTR zstr=zs_new();
-		INT n=0,i=0;
-		/* report debugger: Option to display list of local symbols */
-		n = (stab->tab ? get_table_count(stab->tab) : 0);
-		zs_setf(zstr, _("Display locals (%d)"), n);
-		choices[i++] = strsave(zs_str(zstr));
-		n = (globtab->tab ? get_table_count(globtab->tab) : 0);
-		zs_setf(zstr, _("Display globals (%d)"), n);
-		choices[i++] = strsave(zs_str(zstr));
-		choices[i++] = strsave(_("Pop one level"));
-		choices[i++] = strsave(_("Quit debugger"));
-		ASSERT(i==ARRSIZE(choices));
-dbgloop:
-		rtn = rptui_choose_from_array(_("Report debugger"), ARRSIZE(choices), choices);
-		if (rtn == 3 || rtn == -1)
-			dbg_mode = -99;
-		else if (rtn == 0) {
-			disp_symtab(_("Local variables"), stab);
-			goto dbgloop;
-		}
-		else if (rtn == 1) {
-			disp_symtab(_("Global variables"), globtab);
-			goto dbgloop;
-		}
-		zs_free(&zstr);
-		free_array_strings(ARRSIZE(choices), choices);
-	}
-}
-/*====================================================
- * disp_symtab -- Display contents of a symbol table
- *  This is part of the report language debugger
- *==================================================*/
-static void
-disp_symtab (STRING title, SYMTAB stab)
-{
-	SYMTAB_ITER symtabit=0;
-	INT n = (stab->tab ? get_table_count(stab->tab) : 0);
-	struct dbgsymtab_s sdata;
-	INT bytes = n * sizeof(STRING);
-	if (!n) return;
-	memset(&sdata, 0, sizeof(sdata));
-	sdata.count = n;
-	sdata.locals = (STRING *)stdalloc(bytes);
-	memset(sdata.locals, 0, bytes);
-	/* Now traverse & print the actual entries via disp_symtab_cb() */
-	symtabit = begin_symtab_iter(stab);
-	if (symtabit) {
-		STRING key=0;
-		PVALUE pval=0;
-		while (next_symtab_entry(symtabit, (CNSTRING *)&key, &pval)) {
-			disp_symtab_cb(key, pval, &sdata.locals);
-		}
-		end_symtab_iter(&symtabit);
-	}
-	/* Title of report debugger's list of local symbols */
-	/* TODO: 2003-01-19, we could allow drilldown on lists, tables & sets here */
-	rptui_view_array(title, n, sdata.locals);
-	free_array_strings(n, sdata.locals);
-}
-/*====================================================
- * disp_symtab_cb -- Display one entry in symbol table
- *  This is part of the report language debugger
- *  key:   [IN]  name of current symbol
- *  val:   [IN]  value of current symbol
- *  param: [I/O] points to dbgsymtab_s, where list is being printed
- *==================================================*/
-static BOOLEAN
-disp_symtab_cb (STRING key, PVALUE val, VPTR param)
-{
-	struct dbgsymtab_s * sdata = (struct dbgsymtab_s *)param;
-	ZSTR zline = zs_newn(80), zval;
-	ASSERT(sdata->current < sdata->count);
-	zval = describe_pvalue(val);
-	zs_setf(zline, "%s: %s", key, zs_str(zval));
-	zs_free(&zval);
-	sdata->locals[sdata->current++] = strsave(zs_str(zline));
-	zs_free(&zline);
-	return TRUE; /* continue */
-}
-/*=============================================+
- * prog_error -- Report a run time program error
- *  node:   current parsed node
- *  fmt:    printf style format string
- *  ...:    printf style varargs
- *  See vprog_error
- *============================================*/
-void
-prog_error (PNODE node, STRING fmt, ...)
-{
-	va_list args;
-	va_start(args, fmt);
-	vprog_error(node, fmt, args);
-	va_end(args);
-}
-/*=============================================+
- * vprog_error -- Report a run time program error
- *  node:        current parsed node
- *  fmt, args:   printf style message
- *  ...:    printf style varargs
- * Prints error to the stdout-style curses window
- * and to the report log (if one was specified in config file)
- * Always includes line number of node, if available
- * Only includes file name if not same as previous error
- * Returns static buffer with one-line description
- *============================================*/
-static STRING
-vprog_error (PNODE node, STRING fmt, va_list args)
-{
-	INT num;
-	STRING rptfile;
-	ZSTR zstr=zs_newn(256);
-	static char msgbuff[100];
-	if (rpt_cancelled)
-		return _("Report cancelled");
-	rptfile = getlloptstr("ReportLog", NULL);
-	if (node) {
-		STRING fname = irptinfo(node)->fullpath;
-		INT lineno = iline(node)+1;
-		/* Display filename if not same as last error */
-		if (!eqstr(vprog_prevfile, fname)) {
-			llstrsets(vprog_prevfile, sizeof(vprog_prevfile), uu8, fname);
-			zs_apps(zstr, _("Report file: "));
-			zs_apps(zstr, fname);
-			zs_appc(zstr, '\n');
-			vprog_prevline = -1; /* force line number display */
-		}
-		/* Display line number if not same as last error */
-		if (vprog_prevline != lineno) {
-			vprog_prevline = lineno;
-			if (progparsing)
-				zs_appf(zstr, _("Parsing Error at line %d: "), lineno);
-			else
-				zs_appf(zstr, _("Runtime Error at line %d: "), lineno);
-		}
-	} else {
-		zs_apps(zstr, _("Aborting: "));
-	}
-	zs_appvf(zstr, fmt, args);
-	llwprintf("\n");
-	llwprintf(zs_str(zstr));
-	++progerror;
-	/* if user specified a report error log (in config file) */
-	if (rptfile && rptfile[0]) {
-		FILE * fp = fopen(rptfile, LLAPPENDTEXT);
-		if (fp) {
-			if (progerror == 1) {
-				LLDATE creation;
-				get_current_lldate(&creation);
-				fprintf(fp, "\n%s\n", creation.datestr);
-			}
-			fprintf(fp, zs_str(zstr));
-			fprintf(fp, "\n");
-			fclose(fp);
-		}
-	}
-	if ((num = getlloptint("PerErrorDelay", 0)))
-		sleep(num);
-	zs_free(&zstr);
-	return msgbuff;
-}
 /*=============================================+
  * pa_handle_global -- declare global variable
  * Called directly from generated parser code (ie, from code in yacc.y)
@@ -2328,7 +2114,6 @@ check_rpt_requires (PACTX pactx, STRING fullpath)
 		}
 	}
 	return 0;
-
 }
 /*=============================================+
  * enqueue_parse_error -- Queue up a parsing error
@@ -2356,7 +2141,6 @@ enqueue_parse_error (const char * fmt, ...)
  *  for display during signal processing
  * Created: 2003/07/01 (Matt Emmerton)
  *=============================================*/
-
 ZSTR
 get_report_error_msg (STRING msg)
 {
@@ -2364,8 +2148,24 @@ get_report_error_msg (STRING msg)
 
 	if (progrunning) {
 		char line[20];
-		snprintf(line, sizeof(line), "%d", iline(Pnode)+1);
+		snprintf(line, sizeof(line), "%ld", iline(Pnode)+1);
 		zstr = zprintpic2(_(msg), irptinfo(Pnode)->fullpath, line);
         }
 	return zstr;
 }
+/*=============================================+
+ * clean_orphaned_rptlocks - Clean up any locks on
+ * records that report didn't unlock
+ *=============================================*/
+static
+void clean_orphaned_rptlocks (void)
+{
+	int ct = free_all_rprtlocks();
+	if (ct) {
+		char msg[256];
+		sprintf(msg, _pl("Program forgot to unlock %d record",
+			"Program forgot to unlock %d records", ct), ct);
+		progmessage(MSG_ERROR, msg);
+
+	}
+}
