@@ -75,11 +75,15 @@ typedef struct tag_rptinfo *RPTINFO;
 
 
 /* symbol table data is just table data */
-typedef struct tag_symtab {
+typedef struct tag_symtab *SYMTAB;
+struct tag_symtab {
 	TABLE tab;
-} *SYMTAB;
+	SYMTAB parent;
+	char title[128];
+};
 
-SYMTAB create_symtab(void);
+SYMTAB create_symtab_global(void);
+SYMTAB create_symtab_proc(CNSTRING procname, SYMTAB parstab);
 void delete_symtab_element(SYMTAB stab, STRING iden);
 BOOLEAN in_symtab(SYMTAB stab, STRING key);
 void insert_symtab(SYMTAB stab, STRING iden, PVALUE val);
@@ -275,9 +279,11 @@ PVALUE llrpt_createnode(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_d(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_database(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_date(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_date2jd(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_dateformat(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_datepic(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_dayformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dayofweek(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_deat(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_debug(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_decr(PNODE, SYMTAB, BOOLEAN *);
@@ -343,6 +349,7 @@ PVALUE llrpt_insert(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_inset(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_int(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_intersect(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_jd2date(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_key(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_keysort(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_lastchild(PNODE, SYMTAB, BOOLEAN *);
@@ -411,6 +418,7 @@ PVALUE llrpt_rsort(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_save(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_savenode(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_set(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_setdate(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_setel(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_setlocale(PNODE, SYMTAB, BOOLEAN *);
 PVALUE llrpt_sex(PNODE, SYMTAB, BOOLEAN *);
@@ -493,6 +501,7 @@ PNODE call_node(PACTX pactx, STRING, PNODE);
 PNODE children_node(PACTX pactx, PNODE, STRING, STRING, PNODE);
 void clear_rptinfos(void);
 PNODE continue_node(PACTX pactx);
+void describe_pnode (PNODE node, ZSTR zstr, INT max);
 void debug_show_one_pnode(PNODE);
 CNSTRING get_pvalue_type_name(INT ptype);
 PVALUE evaluate(PNODE, SYMTAB, BOOLEAN*);
@@ -502,6 +511,7 @@ PVALUE evaluate_iden(PNODE, SYMTAB, BOOLEAN*);
 PVALUE evaluate_ufunc(PNODE, SYMTAB, BOOLEAN*);
 PVALUE eval_and_coerce(INT, PNODE, SYMTAB, BOOLEAN*);
 NODE eval_indi(PNODE, SYMTAB, BOOLEAN*, CACHEEL*);
+NODE eval_indi2(PNODE expr, SYMTAB stab, BOOLEAN *eflg, CACHEEL *pcel, PVALUE *pval);
 NODE eval_fam(PNODE, SYMTAB, BOOLEAN*, CACHEEL*);
 PVALUE eval_without_coerce(PNODE node, SYMTAB stab, BOOLEAN *eflg);
 PNODE families_node(PACTX pactx, PNODE, STRING, STRING, STRING, PNODE);
@@ -527,6 +537,7 @@ PNODE icons_node(PACTX pactx, INT ival);
 PNODE iden_node(PACTX pactx, STRING);
 PNODE if_node(PACTX pactx, PNODE, PNODE, PNODE);
 BOOLEAN iistype(PNODE, INT);
+void init_debugger(void);
 void interp_load_lang(void);
 PNODE make_internal_string_node(PACTX pactx, STRING);
 PNODE mothers_node(PACTX pactx, PNODE, STRING, STRING, STRING, PNODE);
