@@ -61,7 +61,6 @@ static void free_float_pvalue(PVALUE val);
 static BOOLEAN is_record_pvaltype(INT valtype);
 static OBJECT pvalue_copy(OBJECT obj, int deep);
 static void pvalue_destructor(VTABLE *obj);
-static void table_pvcleaner(CNSTRING key, UNION uval);
 
 /*********************************************
  * local variables
@@ -322,6 +321,7 @@ clear_pv_indiseq (INDISEQ seq)
  *  from table
  * Created: 2001/03/24, Perry Rapp
  *======================================*/
+#ifdef UNUSED
 static void
 table_pvcleaner (CNSTRING key, UNION uval)
 {
@@ -330,6 +330,7 @@ table_pvcleaner (CNSTRING key, UNION uval)
 	delete_pvalue(val);
 	uval.w = NULL;
 }
+#endif
 /*========================================
  * delete_vptr_pvalue -- Delete a program value
  *  (passed in as a VPTR)
@@ -572,7 +573,8 @@ eq_conform_pvalues (PVALUE val1, PVALUE val2, BOOLEAN *eflg)
 {
 	INT hitype;
 
-	ASSERT(val1 && val2);
+	ASSERT(val1);
+	ASSERT(val2);
 	if (ptype(val1) == ptype(val2)) return;
 	if (ptype(val1) == PNULL)
 		ptype(val1) = ptype(val2);
@@ -704,6 +706,14 @@ which_pvalue_type (PVALUE val)
 	ASSERT(val);
 	return ptype(val);
 }
+/*========================================
+ * is_node_pvalue -- Does pvalue contain PGNODE ?
+ *======================================*/
+BOOLEAN
+is_node_pvalue (PVALUE value)
+{
+	return ptype(value) == PGNODE;
+}
 /*========================================
  * is_record_pvalue -- Does pvalue contain record ?
  *======================================*/
@@ -1040,6 +1050,13 @@ create_pvalue_from_string (CNSTRING str)
 {
 	return create_pvalue(PSTRING, (VPTR)str);
 }
+PVALUE
+create_pvalue_from_zstr (ZSTR * pzstr)
+{
+	PVALUE val = create_pvalue_from_string(zs_str(*pzstr));
+	zs_free(pzstr);
+	return val;
+}
 void
 set_pvalue_string (PVALUE val, CNSTRING str)
 {
