@@ -54,6 +54,7 @@ struct tag_symtab_iter {
  *********************************************/
 
 /* alphabetical */
+static SYMTAB create_symtab(CNSTRING title, SYMTAB parstab);
 static void free_symtable_iter(SYMTAB_ITER symtabit);
 static void record_dead_symtab(SYMTAB symtab);
 static void record_live_symtab(SYMTAB symtab);
@@ -118,16 +119,41 @@ remove_symtab (SYMTAB stab)
 	stdfree(stab);
 }
 /*======================================================
- * create_symtab -- Create a symbol table
+ * create_symtab_proc -- Create a symbol table for a procedure
  *  returns allocated SYMTAB
  *====================================================*/
 SYMTAB
-create_symtab (void)
+create_symtab_proc (CNSTRING procname, SYMTAB parstab)
+{
+	char title[128];
+	llstrncpyf(title, sizeof(title), uu8, "proc: %s", procname);
+	return create_symtab(title, parstab);
+}
+/*======================================================
+ * create_symtab_global -- Create a global symbol table
+ *  returns allocated SYMTAB
+ *====================================================*/
+SYMTAB
+create_symtab_global (void)
+{
+	return create_symtab("global", NULL);
+}
+/*======================================================
+ * create_symtab -- Create a symbol table
+ *  @title:    [IN]  title (procedure or func name)
+ *  @parstab:  [IN]  (dynamic) parent symbol table
+ *                    only for debugging, not for scope
+ *  returns allocated SYMTAB
+ *====================================================*/
+static SYMTAB
+create_symtab (CNSTRING title, SYMTAB parstab)
 {
 	SYMTAB symtab = (SYMTAB)stdalloc(sizeof(*symtab));
 	memset(symtab, 0, sizeof(*symtab));
 
 	symtab->tab = create_table_custom_vptr(delete_vptr_pvalue);
+	symtab->parent = parstab;
+	llstrncpyf(symtab->title, sizeof(symtab->title), uu8, title);
 
 	record_live_symtab(symtab);
 
@@ -150,7 +176,9 @@ static void
 record_dead_symtab (SYMTAB symtab)
 {
 	LIST newlist = create_list2(LISTNOFREE);
-	ASSERT(live_symtabs && length_list(live_symtabs)>0);
+	ASSERT(live_symtabs);
+	ASSERT(length_list(live_symtabs)>0);
+
 	/* hard to delete an element, so create a new shorter list */
 	FORLIST(live_symtabs, e)
 		if (e != symtab)
