@@ -90,7 +90,10 @@ add_indi_by_edit (RFMT rfmt)
 
 /* Create person template for user to edit */
 
-	if (!(fp = fopen(editfile, LLWRITETEXT))) return NULL;
+	if (!(fp = fopen(editfile, LLWRITETEXT)))
+		return NULL;
+	prefix_file_for_edit(fp);
+
 	/* prefer useroption in this db */
 	if ((str = getlloptstr("INDIREC", NULL)))
 		fprintf(fp, "%s\n", str);
@@ -171,7 +174,7 @@ add_new_indi_to_db (RECORD indi0)
 
 	split_indi_old(indi, &name, &refn, &sex, &body, &dumb, &dumb);
 	keynum = getixrefnum();
-	sprintf(key, "I%d", keynum);
+	sprintf(key, "I%ld", keynum);
 	init_new_record(indi0, key);
 	for (node = name; node; node = nsibling(node)) {
 		add_name(nval(node), key);
@@ -254,7 +257,7 @@ prompt_add_child (NODE child, NODE fam, RFMT rfmt)
 
 /* Identify child if caller did not */
 
-	if (!child) child = nztop(ask_for_indi(_(qSidchld), NOCONFIRM, DOASK1));
+	if (!child) child = nztop(ask_for_indi(_(qSidchld), DOASK1));
 	if (!child) return NULL;
 
 /* Identify family if caller did not */
@@ -354,7 +357,7 @@ prompt_add_spouse (RECORD sprec, RECORD frec, BOOLEAN conf)
 
 /* Identify spouse to add to family */
 
-	if (!sprec) sprec = ask_for_indi(_(qSidsadd), NOCONFIRM, DOASK1);
+	if (!sprec) sprec = ask_for_indi(_(qSidsadd), DOASK1);
 	if (!sprec) return FALSE;
 	spouse = nztop(sprec);
 	if ((sex = SEX(spouse)) == SEX_UNKNOWN) {
@@ -512,9 +515,9 @@ add_family_by_edit (RECORD sprec1, RECORD sprec2, RECORD chrec, RFMT rfmt)
 	NODE fam1, fam2=0, husb, wife, chil;
 	XLAT ttmi = transl_get_predefined_xlat(MEDIN);
 	XLAT ttmo = transl_get_predefined_xlat(MINED);
-	STRING msg, key, str;
+	STRING msg=0, key=0, str=0;
 	BOOLEAN emp;
-	FILE *fp;
+	FILE *fp=NULL;
 
 	if (readonly) {
 		message(_(qSronlya));
@@ -531,7 +534,7 @@ add_family_by_edit (RECORD sprec1, RECORD sprec2, RECORD chrec, RFMT rfmt)
 /* Identify first spouse */
 
 	if (!sprec1) 
-		sprec1 = ask_for_indi(_(qSidsps1), NOCONFIRM, NOASK1);
+		sprec1 = ask_for_indi(_(qSidsps1), NOASK1);
 	if (!sprec1) 
 		return NULL;
 	if ((sex1 = SEX(nztop(sprec1))) == SEX_UNKNOWN) {
@@ -542,7 +545,7 @@ add_family_by_edit (RECORD sprec1, RECORD sprec2, RECORD chrec, RFMT rfmt)
 /* Identify optional spouse */
 
 	if (!sprec2)
-		sprec2 = ask_for_indi(_(qSidsps2), NOCONFIRM, DOASK1);
+		sprec2 = ask_for_indi(_(qSidsps2), DOASK1);
 	if (sprec2) {
 		if ((sex2 = SEX(nztop(sprec2))) == SEX_UNKNOWN || 
 			(traditional && sex1 == sex2)) {
@@ -583,6 +586,8 @@ editfam:
 /* Prepare file for user to edit */
 
 	ASSERT(fp = fopen(editfile, LLWRITETEXT));
+	prefix_file_for_edit(fp);
+
 	write_nodes(0, fp, ttmo, fam1, TRUE, TRUE, TRUE);
 	write_nodes(1, fp, ttmo, husb, TRUE, TRUE, TRUE);
 	write_nodes(1, fp, ttmo, wife, TRUE, TRUE, TRUE);
