@@ -93,14 +93,17 @@ static INT browse_fam(RECORD *prec1, RECORD *prec2, INDISEQ *pseq);
 static INT browse_indi_modes(RECORD *prec1, RECORD *prec2, INDISEQ *pseq
 	, INT indimode);
 static INT browse_pedigree(RECORD *prec1, RECORD *prec2, INDISEQ *pseq);
+static RECORD disp_chistory_list(void);
+static RECORD disp_vhistory_list(void);
 static INT display_aux(RECORD rec, INT mode, BOOLEAN reuse);
 static INT get_hist_count(struct hist * histp);
+static INDISEQ get_history_list(struct hist * histp);
 static RECORD goto_fam_child(RECORD frec, int childno);
 static RECORD goto_indi_child(RECORD irec, int childno);
 static BOOLEAN handle_aux_mode_cmds(INT c, INT * mode);
 static INT handle_history_cmds(INT c, RECORD *prec1);
 static RECORD history_back(struct hist * histp);
-static RECORD history_list(struct hist * histp);
+static RECORD do_disp_history_list(struct hist * histp);
 static void history_record(RECORD rec, struct hist * histp);
 static RECORD history_fwd(struct hist * histp);
 static void init_hist(struct hist * histp, INT count);
@@ -159,7 +162,8 @@ prompt_for_browse (RECORD * prec, INT * code, INDISEQ * pseq)
 	STRING key, name;
 
 	/* verify & clear the output arguments */
-	ASSERT(prec && pseq);
+	ASSERT(prec);
+	ASSERT(pseq);
 	*prec = 0;
 	*pseq =0;
 
@@ -203,7 +207,15 @@ main_browse (RECORD rec1, INT code)
 	if (!rec1)
 		prompt_for_browse(&rec1, &code, &seq);
 
-	if (!rec1 && !seq) return;
+	if (!rec1) {
+		if (!seq) return;
+		if (!length_indiseq(seq)) {
+			remove_indiseq(seq);
+			return;
+		}
+	}
+			
+
 
 	/*
 	loop here handle user browsing around through
@@ -359,11 +371,13 @@ browse_indi_modes (RECORD *prec1, RECORD *prec2, INDISEQ *pseq, INT indimode)
 	INT nkeyp, indimodep;
 	RECORD save=0, tmp=0, tmp2=0;
 	INDISEQ seq = NULL;
-	char c2;
 	INT rtn=0; /* return code */
 
-	ASSERT(prec1 && *prec1 && nztype(*prec1)=='I');
-	ASSERT(!*prec2 && !*pseq);
+	ASSERT(prec1);
+	ASSERT(*prec1);
+	ASSERT(nztype(*prec1)=='I');
+	ASSERT(!*prec2);
+	ASSERT(!*pseq);
 
 	/* move working record into current */
 	setrecord(&current, prec1);
@@ -469,11 +483,11 @@ reprocess_indi_cmd: /* so one command can forward to another */
 			}
 			break;
 		case CMD_BROWSE_ZIP_INDI:	/* Zip browse another person */
-			if ((tmp = ask_for_indi(_(qSidpnxt), NOCONFIRM, NOASK1)) != 0)
+			if ((tmp = ask_for_indi(_(qSidpnxt), NOASK1)) != 0)
 				setrecord(&current, &tmp);
 			break;
 		case CMD_BROWSE_ZIP_ANY:	/* Zip browse any record */
-			if ((tmp = ask_for_any(_(qSidnxt), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_any(_(qSidnxt), NOASK1)) != 0) {
 				if (nztype(tmp) != 'I') {
 					setrecord(prec1, &tmp);
 					rtn = BROWSE_UNK;
@@ -624,19 +638,21 @@ reprocess_indi_cmd: /* so one command can forward to another */
 		case CMD_ADD_SOUR: /* add source */
 		case CMD_ADD_EVEN: /* add event */
 		case CMD_ADD_OTHR: /* add other */
-			c2 = (c==CMD_ADD_SOUR ? 'S' : (c==CMD_ADD_EVEN ? 'E' : 'X'));
-			if ((tmp = add_new_rec_maybe_ref(current, c2)) != 0) {
-				if (tmp == current) {
-					c = CMD_EDIT;
-					goto reprocess_indi_cmd; /* forward to edit */
+			{
+				char c2 = (c==CMD_ADD_SOUR ? 'S' : (c==CMD_ADD_EVEN ? 'E' : 'X'));
+				if ((tmp = add_new_rec_maybe_ref(current, c2)) != 0) {
+					if (tmp == current) {
+						c = CMD_EDIT;
+						goto reprocess_indi_cmd; /* forward to edit */
+					}
+					setrecord(prec1, &tmp);
+					rtn = BROWSE_UNK;
+					goto exitbrowse;
 				}
-				setrecord(prec1, &tmp);
-				rtn = BROWSE_UNK;
-				goto exitbrowse;
 			}
 			break;
 		case CMD_TANDEM:	/* Switch to tandem browsing */
-			if ((tmp = ask_for_indi(_(qSidp2br), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_indi(_(qSidp2br), NOASK1)) != 0) {
 				setrecord(prec1, &current);
 				setrecord(prec2, &tmp);
 				rtn = BROWSE_TAND;
@@ -751,8 +767,10 @@ browse_aux (RECORD *prec1, RECORD *prec2, INDISEQ *pseq)
 	char c2;
 	INT rtn=0; /* return code */
 
-	ASSERT(prec1 && *prec1);
-	ASSERT(!*prec2 && !*pseq);
+	ASSERT(prec1);
+	ASSERT(*prec1);
+	ASSERT(!*prec2);
+	ASSERT(!*pseq);
 
 	/* move working record into current */
 	setrecord(&current, prec1);
@@ -818,14 +836,14 @@ reprocess_aux_cmd:
 			}
 			break;
 		case CMD_BROWSE_ZIP_INDI:	/* Zip browse to new person */
-			if ((tmp = ask_for_indi(_(qSidpnxt), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_indi(_(qSidpnxt), NOASK1)) != 0) {
 				setrecord(prec1, &tmp);
 				rtn = BROWSE_UNK;
 				goto exitbrowse;
 			}
 			break;
 		case CMD_BROWSE_ZIP_ANY:	/* Zip browse any record */
-			if ((tmp = ask_for_any(_(qSidnxt), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_any(_(qSidnxt), NOASK1)) != 0) {
 				setrecord(prec1, &tmp);
 				rtn = BROWSE_UNK;
 				goto exitbrowse;
@@ -1027,8 +1045,11 @@ browse_fam (RECORD *prec1, RECORD *prec2, INDISEQ *pseq)
 	char c2;
 	INT rtn=0; /* return code */
 
-	ASSERT(prec1 && *prec1 && nztype(*prec1)=='F');
-	ASSERT(!*prec2 && !*pseq);
+	ASSERT(prec1);
+	ASSERT(*prec1);
+	ASSERT(nztype(*prec1)=='F');
+	ASSERT(!*prec2);
+	ASSERT(!*pseq);
 
 	/* move working record into current */
 	setrecord(&current, prec1);
@@ -1201,7 +1222,7 @@ reprocess_fam_cmd: /* so one command can forward to another */
 				if (nztype(current) != 'F') {
 					setrecord(prec1, &current);
 					rtn = BROWSE_UNK;
-				    goto exitbrowse;
+					goto exitbrowse;
 				}
 				break;
 			}
@@ -1210,14 +1231,14 @@ reprocess_fam_cmd: /* so one command can forward to another */
 			goto exitbrowse;
 			break;
 		case CMD_BROWSE_ZIP_INDI:	/* Zip browse to new person */
-			if ((tmp = ask_for_indi(_(qSidpnxt), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_indi(_(qSidpnxt), NOASK1)) != 0) {
 				setrecord(prec1, &tmp);
 				rtn = BROWSE_INDI;
 				goto exitbrowse;
 			}
 			break;
 		case CMD_BROWSE_ZIP_ANY:	/* Zip browse any record */
-			if ((tmp = ask_for_any(_(qSidnxt), NOCONFIRM, NOASK1)) != 0) {
+			if ((tmp = ask_for_any(_(qSidnxt), NOASK1)) != 0) {
 				setrecord(prec1, &tmp);
 				rtn = BROWSE_UNK;
 				goto exitbrowse;
@@ -1574,7 +1595,7 @@ load_nkey_list (STRING key, struct hist * histp)
 			continue;
 		if (keynum<1 || keynum>MAXKEYNUMBER)
 			continue;
-		snprintf(key, sizeof(key), "%c%d", ntype, keynum);
+		snprintf(key, sizeof(key), "%c%ld", ntype, keynum);
 		strcpy(histp->list[temp].key, key);
 		histp->list[temp].ntype = ntype;
 		histp->list[temp].keynum = keynum;
@@ -1747,36 +1768,68 @@ history_fwd (struct hist * histp)
  *  returns NULL if no history or if user cancels
  * Created: 2002/06/23, Perry Rapp
  *================================================*/
-RECORD
+static RECORD
 disp_vhistory_list (void)
 {
-	return history_list(&vhist);
+	return do_disp_history_list(&vhist);
 }
 /*==================================================
  * disp_chistory_list -- show user the changed history list
  *  returns NULL if no history or if user cancels
  * Created: 2002/06/23, Perry Rapp
  *================================================*/
-RECORD
+static RECORD
 disp_chistory_list (void)
 {
-	return history_list(&chist);
+	return do_disp_history_list(&chist);
 }
 /*==================================================
- * history_list -- let user choose from history list
+ * get_chistory_list -- return indiseq of change history
+ *  returns NULL if no history
+ *================================================*/
+INDISEQ
+get_chistory_list (void)
+{
+	return get_history_list(&chist);
+}
+/*==================================================
+ * get_vhistory_list -- Return indiseq of visit history
+ *  returns NULL if no history
+ *================================================*/
+INDISEQ
+get_vhistory_list (void)
+{
+	return get_history_list(&vhist);
+}
+/*==================================================
+ * do_disp_history_list -- let user choose from history list
  *  calls message(nohist) if none found
  *  returns NULL if no history or if user cancels
  * Created: 2001/04/12, Perry Rapp
  *================================================*/
 static RECORD
-history_list (struct hist * histp)
+do_disp_history_list (struct hist * histp)
+{
+	INDISEQ seq = get_history_list(histp);
+	RECORD rec=0;
+
+	if (!seq) {
+		message(_(qSnohist));
+		return NULL;
+	}
+	rec = choose_from_indiseq(seq, DOASK1, _(qSidhist), _(qSidhist));
+	remove_indiseq(seq);
+	return rec;
+}
+/*==================================================
+ * get_history_list -- return specified history list as indiseq
+ *================================================*/
+static INDISEQ
+get_history_list (struct hist * histp)
 {
 	INDISEQ seq=0;
-	NODE node=0;
-	RECORD rec=0;
 	INT next, prev;
 	if (!histp->size || histp->start==-1) {
-		message(_(qSnohist));
 		return NULL;
 	}
 	/* add all items of history to seq */
@@ -1784,6 +1837,7 @@ history_list (struct hist * histp)
 	prev = -1;
 	next = histp->start;
 	while (1) {
+		NODE node=0;
 		nkey_to_node(&histp->list[next], &node);
 		if (node) {
 			STRING key = node_to_key(node);
@@ -1794,9 +1848,7 @@ history_list (struct hist * histp)
 		if (next == histp->past_end)
 			break; /* finished them all */
 	}
-	rec = choose_from_indiseq(seq, DOASK1, _(qSidhist), _(qSidhist));
-	remove_indiseq(seq);
-	return rec;
+	return seq;
 }
 /*==================================================
  * ask_clear_history -- delete vist history
