@@ -41,6 +41,9 @@
 #include "llinesi.h"
 #include "feedback.h"
 
+/*********************************************
+ * external/imported variables
+ *********************************************/
 
 extern BOOLEAN traditional;
 extern STRING qSiredit, qScfpmrg, qSnopmrg, qSnoqmrg, qSnoxmrg, qSnofmrg;
@@ -51,6 +54,16 @@ static void merge_fam_links(NODE, NODE, NODE, NODE, INT);
 static NODE remove_dupes(NODE, NODE);
 static NODE sort_children(NODE, NODE);
 
+
+/*********************************************
+ * local function prototypes
+ *********************************************/
+
+/* alphabetical */
+static void check_indi_lineage_links(NODE indi);
+static void check_fam_lineage_links(NODE fam);
+
+
 /*================================================================
  * merge_two_indis -- Merge first person to second; data from both
  *   are put in file that user edits; first person removed
@@ -85,7 +98,8 @@ merge_two_indis (NODE indi1, NODE indi2, BOOLEAN conf)
 
 /* Do start up checks */
 
-	ASSERT(indi1 && indi2);
+	ASSERT(indi1);
+	ASSERT(indi2);
 	ASSERT(eqstr("INDI", ntag(indi1)));
 	ASSERT(eqstr("INDI", ntag(indi2)));
 	if (readonly) {
@@ -102,6 +116,7 @@ merge_two_indis (NODE indi1, NODE indi2, BOOLEAN conf)
 	famc1 = FAMC(indi1);
 	famc2 = FAMC(indi2);
 /*LOOSEEND -- THIS CHECK IS NOT GOOD ENOUGH */
+/* comment from merge.c 1.2 2000-01-03 nozell */
 	if (traditional) {
 		if (famc1 && famc2 && nestr(nval(famc1), nval(famc2))) {
 			if (!ask_yes_or_no_msg(_(qSmgsfam), _(qSmgconf))) {
@@ -117,6 +132,11 @@ merge_two_indis (NODE indi1, NODE indi2, BOOLEAN conf)
 		return NULL;
 	}
 
+
+/* sanity check lineage links */
+	check_indi_lineage_links(indi1);
+	check_indi_lineage_links(indi2);
+
 /* Split original persons */
 
 	/* If we are successful, the original indi1 will be deleted
@@ -395,15 +415,25 @@ merge_two_indis (NODE indi1, NODE indi2, BOOLEAN conf)
 	free_nodes(indi4);
 
 	remove_indi_by_root(indi01);	/* this is the original indi1 */
+
+/* sanity check lineage links */
+	check_indi_lineage_links(indi02);
+
 	return node_to_record(indi02);   /* this is the updated indi2 */
 }
 /*=================================================================
  * merge_two_fams -- Merge first family into second; data from both
  *   are put in file that user edits; first family removed
+ *---------------------------------------------------------------
+ *  These are the four main variables
+ *   fam1 - upper family in database -- fam1 is merged into fam2
+ *   fam2 - lower family in database -- fam1 is merged into this person
+ *   fam3 - temporary which is the merged version for the user to edit
+ *   fam4 - merged version of the two persons after editing
+ *     the nodes inside fam4 are stored into fam2 & to dbase at the very end
  *===============================================================*/
 RECORD
-merge_two_fams (NODE fam1,
-                NODE fam2)
+merge_two_fams (NODE fam1, NODE fam2)
 {
 	NODE husb1, wife1, chil1, rest1, husb2, wife2, chil2, rest2;
 	NODE fref1, fref2;
@@ -419,7 +449,8 @@ merge_two_fams (NODE fam1,
 		message(_(qSronlym));
 		return NULL;
 	}
-	ASSERT(fam1 && fam2);
+	ASSERT(fam1);
+	ASSERT(fam2);
 	ASSERT(eqstr("FAM", ntag(fam1)));
 	ASSERT(eqstr("FAM", ntag(fam2)));
 	if (fam1 == fam2) {
@@ -427,18 +458,24 @@ merge_two_fams (NODE fam1,
 		return NULL;
 	}
 
+/* sanity check lineage links */
+	check_fam_lineage_links(fam1);
+	check_fam_lineage_links(fam2);
+
 /* Check restrictions on families */
 	split_fam(fam1, &fref1, &husb1, &wife1, &chil1, &rest1);
 	split_fam(fam2, &fref2, &husb2, &wife2, &chil2, &rest2);
 	if (traditional) {
+		BOOLEAN ok = TRUE;
 		if (husb1 && husb2 && nestr(nval(husb1), nval(husb2))) {
 			message(_(qSdhusb));
-			join_fam(fam1, fref1, husb1, wife1, chil1, rest1);
-			join_fam(fam2, fref2, husb2, wife2, chil2, rest2);
-			return NULL;
+			ok = FALSE;
 		}
-		if (wife1 && wife2 && nestr(nval(wife1), nval(wife2))) {
+		if (ok && wife1 && wife2 && nestr(nval(wife1), nval(wife2))) {
 			message(_(qSdwife));
+			ok = FALSE;
+		}
+		if (!ok) {
 			join_fam(fam1, fref1, husb1, wife1, chil1, rest1);
 			join_fam(fam2, fref2, husb2, wife2, chil2, rest2);
 			return NULL;
@@ -518,6 +555,11 @@ merge_two_fams (NODE fam1,
 	join_fam(fam2, fref4, husb4, wife4, chil4, rest4);
 	resolve_refn_links(fam2);
 	fam_to_dbase(fam2);
+
+
+/* sanity check lineage links */
+	check_fam_lineage_links(fam2);
+	
 	return node_to_record(fam2);
 }
 /*================================================================
@@ -610,6 +652,7 @@ sort_children (NODE chil1,
 	NODE copy1, copy2, chil3, prev, kid1, kid2;
 	STRING year1, year2;
 	INT int1, int2;
+	/* copy1 contains all children in chil1 not in chil2 */
 	copy1 = remove_dupes(chil1, chil2);
 	copy2 = copy_nodes(chil2, TRUE, TRUE);
 	int1 = int2 = 1;
@@ -661,10 +704,17 @@ sort_children (NODE chil1,
 }
 /*=================================================
  * remove_dupes -- Return all in list1 not in list2
+ *  Creates a copy of list1 then traverses it
+ *   removing any items which are in list2
+ *  Then returns this new trimmed list.
+ * This is pretty inefficient algorithm, as every item
+ *  in list1 is compared against every item in list2
+ * It would be more efficient to make a table of items
+ *  on list2 first, and then use that to check each item
+ *  in list1.
  *===============================================*/
 static NODE
-remove_dupes (NODE list1,
-              NODE list2)
+remove_dupes (NODE list1, NODE list2)
 {
 	NODE copy1 = copy_nodes(list1, TRUE, TRUE);
 	NODE prev1, next1, curs1, curs2;
@@ -690,3 +740,232 @@ remove_dupes (NODE list1,
 	}
 	return copy1;
 }
+/*=================================================
+ * check_indi_lineage_links -- Check all families of
+ *  this person to make sure they point back to this person
+ *===============================================*/
+static void
+check_indi_lineage_links (NODE indi)
+{
+	NODE name=0, refn=0, sex=0, body=0, famc=0, fams=0;
+	NODE curs=0; /* for travesing node lists */
+	TABLE memtab = memtab = create_table_int();
+	TABLE_ITER tabit=0;
+	CNSTRING famkey=0; /* used inside traversal loops */
+	INT count=0;
+	CNSTRING ikey = nxref(indi);
+
+	/* sanity check record is not deleted */
+	ASSERT(is_key_in_use(ikey));
+
+/* Now validate lineage links of this person */
+	split_indi_old(indi, &name, &refn, &sex, &body, &famc, &fams);
+
+	/*
+	Make table listing all families this person is spouse in
+	(& how many times each)
+	*/
+	for (curs = fams; curs; curs = nsibling(curs)) {
+		famkey = rmvat(nval(curs));
+		if (!eqstr(ntag(curs), "FAMS")) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0]), _("Bad spouse tag: %s"), ntag(curs));
+			FATAL2(msg);
+		}
+		increment_table_int(memtab, famkey);
+	}
+
+	/*
+	Check that all listed families contain person as spouse as many times
+	as expected
+	*/
+	tabit = begin_table_iter(memtab);
+	while (next_table_int(tabit, &famkey, &count)) {
+		NODE fam = key_to_fam(famkey);
+		/*
+		count how many times our main person (ikey)
+		occurs in this family (fam) as a spouse (HUSB or WIFE)
+		*/
+		INT occur = 0;
+		for (curs = nchild(fam); curs; curs = nsibling(curs)) {
+			if (eqstr(ntag(curs), "HUSB") || eqstr(ntag(curs), "WIFE")) {
+				if (eqstr(nval(curs), ikey)) {
+					++occur;
+				}
+			}
+		}
+		if (count != occur) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0])
+				, _("Mismatched lineage spouse links between %s and %s: %ld and %ld")
+				, ikey, famkey, count, occur);
+			FATAL2(msg);
+		}
+	}
+	destroy_table(memtab);
+	memtab = create_table_int();
+
+	/*
+	Make table listing all families this person is child in
+	(& how many times each)
+	*/
+	for (curs = famc; curs; curs = nsibling(curs)) {
+		famkey = rmvat(nval(curs));
+		if (!eqstr(ntag(curs), "FAMC")) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0]), _("Bad child tag: %s"), ntag(curs));
+			FATAL2(msg);
+		}
+		increment_table_int(memtab, famkey);
+	}
+
+	/*
+	Check that all listed families contain person as child (CHIL) as many times
+	as expected
+	*/
+	tabit = begin_table_iter(memtab);
+	while (next_table_int(tabit, &famkey, &count)) {
+		NODE fam = key_to_fam(famkey);
+		/*
+		count how many times our main person (ikey)
+		occurs in this family (fam) as a child (CHIL)
+		*/
+		INT occur = 0;
+		for (curs = nchild(fam); curs; curs = nsibling(curs)) {
+			if (eqstr(ntag(curs), "CHIL")) {
+				if (eqstr(nval(curs), ikey)) {
+					++occur;
+				}
+			}
+		}
+		if (count != occur) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0])
+				, _("Mismatched lineage child links between %s and %s: %ld and %ld")
+				, ikey, famkey, count, occur);
+			FATAL2(msg);
+		}
+	}
+
+	join_indi(indi, name, refn, sex, body, famc, fams);
+	destroy_table(memtab);
+}
+/*=================================================
+ * check_fam_lineage_links -- Check all persons of
+ *  this family to make sure they point back to this family
+ *===============================================*/
+static void
+check_fam_lineage_links (NODE fam)
+{
+	NODE fref=0, husb=0, wife=0, chil=0, rest=0;
+	NODE curs=0; /* for travesing node lists */
+	TABLE memtab = memtab = create_table_int();
+	TABLE_ITER tabit=0;
+	CNSTRING indikey=0; /* used inside traversal loops */
+	INT count=0;
+	CNSTRING fkey = nxref(fam);
+
+	/* sanity check record is not deleted */
+	ASSERT(is_key_in_use(fkey));
+	
+/* Now validate lineage links of this family */
+	split_fam(fam, &fref, &husb, &wife, &chil, &rest);
+
+	/*
+	Make table listing all spouses in this family
+	(& how many times each)
+	*/
+	for (curs = husb; curs; curs = nsibling(curs)) {
+		indikey = rmvat(nval(curs));
+		if (!eqstr(ntag(curs), "HUSB")) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0]), _("Bad HUSB tag: %s"), ntag(curs));
+			FATAL2(msg);
+		}
+		increment_table_int(memtab, indikey);
+	}
+	for (curs = wife; curs; curs = nsibling(curs)) {
+		indikey = rmvat(nval(curs));
+		if (!eqstr(ntag(curs), "WIFE")) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0]), _("Bad HUSB tag: %s"), ntag(curs));
+			FATAL2(msg);
+		}
+		increment_table_int(memtab, indikey);
+	}
+
+	/*
+	Check that all listed persons contain family as FAMS as many times
+	as expected
+	*/
+	tabit = begin_table_iter(memtab);
+	while (next_table_int(tabit, &indikey, &count)) {
+		NODE indi = key_to_indi(indikey);
+		/*
+		count how many times our main family (fkey)
+		occurs in this person (indi) as a spousal family (FAMS)
+		*/
+		INT occur = 0;
+		for (curs = nchild(indi); curs; curs = nsibling(curs)) {
+			if (eqstr(ntag(curs), "FAMS")) {
+				if (eqstr(nval(curs), fkey)) {
+					++occur;
+				}
+			}
+		}
+		if (count != occur) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0])
+				, _("Mismatched lineage spouse links between %s and %s: %ld and %ld")
+				, fkey, indikey, count, occur);
+			FATAL2(msg);
+		}
+	}
+	destroy_table(memtab);
+	memtab = create_table_int();
+
+	/*
+	Make table listing all families this person is child in
+	(& how many times each)
+	*/
+	for (curs = chil; curs; curs = nsibling(curs)) {
+		indikey = rmvat(nval(curs));
+		if (!eqstr(ntag(curs), "CHIL")) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0]), _("Bad child tag: %s"), ntag(curs));
+			FATAL2(msg);
+		}
+		increment_table_int(memtab, indikey);
+	}
+
+	/*
+	Check that all listed families contain person as FAMC as many times
+	as expected
+	*/
+	tabit = begin_table_iter(memtab);
+	while (next_table_int(tabit, &indikey, &count)) {
+		NODE indi = key_to_indi(indikey);
+		/*
+		count how many times our main family (fkey)
+		occurs in this person (indi) as a parental family (FAMC)
+		*/
+		INT occur = 0;
+		for (curs = nchild(indi); curs; curs = nsibling(curs)) {
+			if (eqstr(ntag(curs), "FAMC")) {
+				if (eqstr(nval(curs), fkey)) {
+					++occur;
+				}
+			}
+		}
+		if (count != occur) {
+			char msg[512];
+			snprintf(msg, sizeof(msg)/sizeof(msg[0])
+				, _("Mismatched lineage child links between %s and %s: %ld and %ld")
+				, fkey, indikey, count, occur);
+			FATAL2(msg);
+		}
+	}
+	
+	
+	join_fam(fam, fref, husb, wife, chil, rest);
+}
