@@ -90,6 +90,7 @@ static FILE *f_flog = 0;
 static char f_logpath[MAXPATHLEN] = "import.log";
 
 static STRING qSundrec      = N_("Record %s is referred to but not defined.");
+static STRING qSundrecl     = N_("Line %d: Reference to undefined record %s");
 static STRING qSlinlev1     = N_("Line %d: Tag %s found in unexpected record: %s %s.");
 
 ELMNT *index_data = NULL;
@@ -224,8 +225,10 @@ validate_gedcom (IMPORT_FEEDBACK ifeed, FILE *fp)
 					rec_type = OTHR_REC;
 					other = add_othr_defn(ifeed, xref, flineno);
 				}
-				if (ifeed && ifeed->added_rec_fnc)
-					ifeed->validated_rec_fnc(tag[0], tag, count);
+				if (ifeed && ifeed->validated_rec_fnc) {
+					char ctype = (rec_type==OTHR_REC) ? 'X': tag[0];
+					ifeed->validated_rec_fnc(ctype, tag, count);
+				}
 			}
 		} else {
 			/* specific handling for specific record types */
@@ -266,7 +269,8 @@ create_elmnt (CHAR eltype, CNSTRING xref)
 	ELMNT el = (ELMNT) stdalloc(sizeof(*el));
 	memset(el, 0, sizeof(*el));
 	Type(el) = eltype;
-	Key(el) = strsave(xref);
+	if (xref)
+		Key(el) = strsave(xref);
 	return el;
 }
 /*=======================================
@@ -300,9 +304,8 @@ add_indi_defn (IMPORT_FEEDBACK ifeed, STRING xref, INT line, ELMNT *pel)
 		return -2;
 	}
 	if ((dex = xref_to_index(xref)) == -1) {
-		*pel = el = (ELMNT) stdalloc(sizeof(*el));
-		Type(el) = INDI_REC;
-		Key(el) = xref = strsave(xref);
+		*pel = el = create_elmnt(INDI_REC, xref);
+		xref = Key(el); /* dup'd copy of xref */
 		Line(el) = 0;
 		New(el) = NULL;
 		Sex(el) = 0;
@@ -345,16 +348,15 @@ add_fam_defn (IMPORT_FEEDBACK ifeed, STRING xref, INT line)
 		return -1;
 	}
 	if ((dex = xref_to_index(xref)) == -1) {
-		el = (ELMNT) stdalloc(sizeof(*el));
-		Type(el) = FAM_REC;
-		Key(el) = xref = strsave(xref);
+		el = create_elmnt(FAM_REC, xref);
 		Line(el) = 0;
 		New(el) = NULL;
 		Male(el) = 0;
 		Fmle(el) = 0;
 		dex = add_to_structures(xref, el);
-	} else
+	} else {
 		el = index_data[dex];
+	}
 	if (KNOWNTYPE(el) && Type(el) != FAM_REC) {
 		handle_err(ifeed, qSmatfam, line, xref);
 		return -1;
@@ -390,9 +392,8 @@ add_sour_defn (IMPORT_FEEDBACK ifeed, STRING xref, INT line)
 		return -1;
 	}
 	if ((dex = xref_to_index(xref)) == -1) {
-		el = (ELMNT) stdalloc(sizeof(*el));
-		Type(el) = SOUR_REC;
-		Key(el) = xref = strsave(xref);
+		el = create_elmnt(SOUR_REC, xref);
+		xref = Key(el); /* dup'd copy of xref */
 		Line(el) = 0;
 		New(el) = NULL;
 		dex = add_to_structures(xref, el);
@@ -435,9 +436,7 @@ add_even_defn (IMPORT_FEEDBACK ifeed, STRING xref, INT line)
 		return -1;
 	}
 	if ((dex = xref_to_index(xref)) == -1) {
-		el = (ELMNT) stdalloc(sizeof(*el));
-		Type(el) = EVEN_REC;
-		Key(el) = xref = strsave(xref);
+		el = create_elmnt(EVEN_REC, xref);
 		Line(el) = 0;
 		New(el) = NULL;
 		dex = add_to_structures(xref, el);
@@ -480,9 +479,7 @@ add_othr_defn (IMPORT_FEEDBACK ifeed, STRING xref, INT line)
 		return -1;
 	}
 	if ((dex = xref_to_index(xref)) == -1) {
-		el = (ELMNT) stdalloc(sizeof(*el));
-		Type(el) = OTHR_REC;
-		Key(el) = xref = strsave(xref);
+		el = create_elmnt(OTHR_REC, xref);
 		Line(el) = 0;
 		New(el) = NULL;
 		dex = add_to_structures(xref, el);
@@ -763,7 +760,8 @@ addmissingkeys (INT t)          /* type of record: INDI_REC ... */
 			ELMNT el = index_data[i];
 			if(Type(el) == t) {
 				j = atoi(Key(el)+1);
-				ASSERT((j>0) && (j <= tmax));
+				ASSERT(j>0);
+				ASSERT(j <= tmax);
 				kp[j] = 1;
 			}
 		}
@@ -806,7 +804,7 @@ check_references (IMPORT_FEEDBACK ifeed)
 		case EVEN_REC: check_even_links(ifeed, el); break;
 		case SOUR_REC: check_sour_links(ifeed, el); break;
 		case OTHR_REC: check_othr_links(ifeed, el); break;
-		default: handle_err(ifeed, qSundrec, Key(el));
+		default: handle_err(ifeed, qSundrecl, Line(el), Key(el));
 		}
 	}
 }
@@ -904,9 +902,7 @@ handle_value (STRING val, INT line)
 	if (!pointer_value(val)) return;
 	xref = rmvat(val);
 	if (xref_to_index(xref) != -1) return;
-	el = (ELMNT) stdalloc(sizeof(*el));
-	Type(el) = UNKN_REC;
-	Key(el) = xref = strsave(xref);
+	el = create_elmnt(UNKN_REC, xref);
 	New(el) = NULL;
 	Line(el) = line;
 	add_to_structures(xref, el);
@@ -1060,7 +1056,9 @@ scan_header (FILE * fp, TABLE metadatatab, ZSTR * zerr)
 	ZSTR zpath = zs_new();
 	*zerr = 0;
 	for (linno=1; 1; ++linno) {
-		XLAT xlat=0; /* no codeset translation yet */
+		XLAT xlat=0;
+		/* no codeset translation yet, b/c we've not found the file's
+		encoding declaration yet */
 		INT rc;
 		STRING xref, tag, val, msg;
 		lastoff = ftell(fp);
