@@ -90,6 +90,8 @@ chartype (INT c)
 BOOLEAN
 isnumch (INT c)
 {
+	if (c<0 || c>0x7F) return FALSE;
+	/* Now we know it is ASCII range */
 #ifndef OS_NOCTYPE
 	return (isdigit(c));
 #else
@@ -105,6 +107,8 @@ isnumch (INT c)
 BOOLEAN
 iswhite (INT c)
 {
+	if (c<0 || c>0x7F) return FALSE;
+	/* Now we know it is ASCII range */
 #ifndef OS_NOCTYPE
 	return (isspace(c));
 #else
@@ -175,8 +179,9 @@ ll_tolower (INT c)
 #endif
 }
 /*===============================
- * eqstr_ex -- Are two strings equal ?
+ * eqstr_ex -- Are two strings equal (case-sensitive)?
  *  This is just eqstr extended to handle empty or null strings
+ *  Like eqstr, this is byte-by-byte comparison, no locale, no UTF-8
  *=============================*/
 BOOLEAN
 eqstr_ex (CNSTRING s1, CNSTRING s2)
