@@ -76,9 +76,9 @@ int opt_mychar = 0;
  * errinfo -- holds stats on a type of error
  *========================================*/
 struct errinfo {
-	INT err;
-	INT err_count;
-	INT fix_count;
+	int err;
+	int err_count;
+	int fix_count;
 	STRING desc;
 };
 /*==================================
@@ -153,6 +153,7 @@ static void report_fix(INT err, STRING fmt, ...);
 static void report_progress(STRING fmt, ...);
 static void report_results(void);
 static void validate_errs(void);
+static void vcrashlog(int newline, const char * fmt, va_list args);
 
 /*********************************************
  * local variables
@@ -341,12 +342,13 @@ check_ghosts (void)
 		while (!is_empty_list(tofix)) {
 			rec = (NAMEREFN_REC *) dequeue_list(tofix);
 			remove_name(rec->namerefn, rec->key);
-			errs[rec->err].fix_count++;
+			++errs[rec->err].fix_count;
 			free_namerefn(rec);
 		}
 	}
 
-	ASSERT(is_empty_list(tofix) && !soundexseq);
+	ASSERT(is_empty_list(tofix));
+	ASSERT(!soundexseq);
 
 	soundexseq = create_indiseq_sval();
 	/* soundexseq is used inside cgr_callback, across calls */
@@ -882,7 +884,7 @@ process_fam (RECORD rec)
 			/* look for family (key) in child */
 			if (!find_xref(key, child, "FAMC", NULL)) {
 				report_error(ERR_EXTRACHILD
-					, _("Improper child (%s) in family (%s)")
+					, _("Improper child: Child (%s) without FAMC reference to family (%s)")
 					, printkey(chilkey), key);
 			}
 		}
@@ -1063,7 +1065,7 @@ check_set (INDISEQ seq, char ctype)
 				, ctype, i);
 			if (todo.fix_deletes) {
 				char key[33];
-				sprintf(key, "%c%d", ctype, i);
+				sprintf(key, "%c%ld", ctype, i);
 				if (mark_deleted_record_as_deleted(key)) {
 					report_fix(ERR_UNDELETED
 						, _("Fixed missing undeleted record %c%d")
@@ -1112,7 +1114,8 @@ check_btree (BTREE btr)
 	INDEX index = bmaster(BTR);
 	INT mk1 = bkfile(btr).k_mkey;
 	if (ixself(index) != mk1) {
-		printf(_("Master fkey misaligned (%d != %d)\n"), ixself(index), mk1);
+		printf(_("Master fkey misaligned"));
+		printf("(%ld != %ld\n", ixself(index), mk1);
 		return FALSE;
 	}
 	check_index(btr, index, fkeytab, NULL, NULL);
@@ -1145,7 +1148,8 @@ check_index (BTREE btr, INDEX index, TABLE fkeytab, RKEY * lo, RKEY * hi)
 		}
 		newix = readindex(btr, fkey, TRUE);
 		if (!newix) {
-			printf(_("Error loading index at key %d\n"), i);
+			printf(_("Error loading index at key"));
+			printf("%ld\n", i);
 			printblock((BLOCK)index);
 		}
 		/* figure upper & lower bounds of what keys should be in the child */
@@ -1208,7 +1212,8 @@ check_keys (BLOCK block, RKEY * lo, RKEY * hi)
 		if (i<n) {
 			INT rel = cmpkeys(&rkeys(block, i), &rkeys(block, i+1));
 			if (rel >= 0) {
-				printf(_("Key %d not below next key\n"), i);
+				printf(_("Key not below next key"));
+				printf(": %ld\n", i);
 				printblock(block);
 				ok = FALSE;
 			}
@@ -1236,12 +1241,13 @@ printblock (BLOCK block)
 static void
 validate_errs (void)
 {
-	INT i;
+	int i;
 	for (i=0; i<ARRSIZE(errs); i++) {
 		if (errs[i].err != i) {
 			fprintf(stderr
 				, _("Invalid errs array[%d] in dbverify - fix program\n")
 				, i);
+			print_version("dbverify");
 			FATAL();
 		}
 	}
@@ -1301,6 +1307,8 @@ main (int argc, char **argv)
 	BOOLEAN allchecks=FALSE; /* if user requested all checks */
 	INT returnvalue=1;
 	STRING crashlog=NULL;
+	INT lldberrnum=0;
+	int i=0;
 
 	/* initialize all the low-level library code */
 	init_stdlib();
@@ -1313,7 +1321,7 @@ main (int argc, char **argv)
 #endif /* HAVE_SETLOCALE */
 
 #if ENABLE_NLS
-	bindtextdomain(PACKAGE, LOCALEDIR);
+	ll_bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 #endif
 
@@ -1324,6 +1332,20 @@ main (int argc, char **argv)
 	_fmode = O_BINARY;	/* default to binary rather than TEXT mode */
 #endif
 
+	/* handle conventional arguments --version and --help */
+	/* needed for help2man to synthesize manual pages */
+	for (i=1; i<argc; ++i) {
+		if (!strcmp(argv[i], "--version")) {
+			print_version("dbverify");
+			return 0;
+		}
+		if (!strcmp(argv[i], "--help")
+			|| !strcmp(argv[i], "-?")) {
+			print_usage();
+			return 0;
+		}
+	}
+
 	if (argc != 3 || argv[1][0] != '-' || argv[1][1] == '\0') {
 		print_usage();
 		goto done;
@@ -1346,6 +1368,7 @@ main (int argc, char **argv)
 		case 'm': todo.check_missing_data_records=TRUE; break;
 		case 'M': todo.fix_missing_data_records=TRUE; break;
 		case 'D': todo.fix_deletes=TRUE; break;
+		case 'v': print_version("llexec"); goto done;
 		case 'h':
 		default: print_usage(); goto done;
 		}
@@ -1360,6 +1383,7 @@ main (int argc, char **argv)
 		todo.check_missing_data_records = 1;
 
 	/* initialize options & misc. stuff */
+	llgettext_set_default_localedir(LOCALEDIR);
 	if (!init_lifelines_global(0, &msg, 0)) {
 		printf("%s\n", msg);
 		goto done;
@@ -1369,10 +1393,11 @@ main (int argc, char **argv)
 	crashlog = getlloptstr("CrashLog_dbverify", NULL);
 	if (!crashlog) { crashlog = "Crashlog_dbverify.log"; }
 	crash_setcrashlog(crashlog);
-	
-	if (!(BTR = bt_openbtree(dbname, cflag, writ, immut))) {
+
+	/* NB: This assumes btree database */
+	if (!(BTR = bt_openbtree(dbname, cflag, writ, immut, &lldberrnum))) {
 		char buffer[256];
-		describe_dberror(bterrno, buffer, ARRSIZE(buffer));
+		describe_dberror(lldberrnum, buffer, ARRSIZE(buffer));
 		puts(buffer);
 		goto done;
 	}
@@ -1392,7 +1417,8 @@ main (int argc, char **argv)
 		printf(_(qSbaddb));
 		goto done;
 	}
-	printf("Checking %s\n", dbname);
+	printf(_("Checking %s"), dbname);
+	puts("");
 
 	/* all checks - if any new ones, have to update this */
 	if (allchecks) {
@@ -1492,16 +1518,41 @@ __fatal (STRING file, int line, CNSTRING details)
 	exit(1);
 }
 /*===============================
- * __crashlog -- Details preceding a fatal error
+ * vcrashlog -- Send crash info to screen
+ *  internal implementation
+ *=============================*/
+static void
+vcrashlog (int newline, const char * fmt, va_list args)
+{
+	vprintf(fmt, args);
+	if (newline) {
+		printf("\n");
+	}
+}
+/*===============================
+ * crashlog -- Send string to crash log and screen
  *=============================*/
 void
 crashlog (STRING fmt, ...)
 {
 	va_list args;
 	va_start(args, fmt);
-	vprintf(fmt, args);
+	vcrashlog(0, fmt, args);
 	va_end(args);
 }
+/*===============================
+ * crashlogn -- Send string to crash log and screen
+ *  add carriage return to end line
+ *=============================*/
+void
+crashlogn (STRING fmt, ...)
+{
+	va_list args;
+	va_start(args, fmt);
+	vcrashlog(1, fmt, args);
+	va_end(args);
+}
+
 /*===============================
  * printkey -- Displayable version of key
  *  same as key, except for NULL keys
